@@ -3,7 +3,10 @@
 # Note: this script requires MacOS X 10.2 or greater, and builds diskimages
 # which require MacOS X 10.1 or greater to install.
 #
-# Currently (at least is built on 10.6) 10.6 is required to run.
+# Currently (at least if built on 10.6) at least 10.6 is required to run.
+#
+# You probably need to have Xcode installed - you can download this for free
+# from Apple: http://developer.apple.com/xcode/
 #
 # Run from the unpacked survex-1.1.X directory like so:
 #
@@ -33,21 +36,34 @@
 
 set -e
 
+# 2.8.12 doesn't work:
+# /bin/sh: line 0: cd: ../build/bakefiles/wxpresets/presets: No such file or directory
+# cp: wx.bkl: No such file or directory
+# [...]
 WXVERSION=2.8.11
 
-# Fix to work for ppc too...
-#arch_flags='-arch i386 -arch ppc'
+# Sadly, you can only specify one arch via -arch at a time (a restriction of
+# the wxWidgets build system).
+#
+# Using -arch i386 produces a build which will also work on 64-bit Intel Macs.
+# If you want a build which *only* works on 64 bit Intel Macs, then use
+# arch_flags='-arch x86_64' instead.
+#
+# To build for older machines with a ppc CPU, you want arch_flags='-arch ppc'
+# instead.
 arch_flags='-arch i386'
 if [ -z "${WX_CONFIG+set}" ] && [ "x$1" != "x--no-install-wx" ] ; then
   if test -x WXINSTALL/bin/wx-config ; then
     :
   else
     prefix=`pwd`/WXINSTALL
-    test -f wxWidgets-$WXVERSION.tar.bz2 || \
-      curl -O ftp://ftp.wxwidgets.org/pub/$WXVERSION/wxWidgets-$WXVERSION.tar.bz2
-    test -d wxWidgets-$WXVERSION || tar jxvf wxWidgets-$WXVERSION.tar.bz2
-    test -d wxWidgets-$WXVERSION/build || mkdir wxWidgets-$WXVERSION/build
-    cd wxWidgets-$WXVERSION/build
+    wxtarball=wxWidgets-$WXVERSION.tar.bz2
+    test -f "$wxtarball" || \
+      curl -O "ftp://ftp.wxwidgets.org/pub/$WXVERSION/$wxtarball"
+    echo "+++ Extracting $wxtarball"
+    test -d "wxWidgets-$WXVERSION" || tar jxf "$wxtarball"
+    test -d "wxWidgets-$WXVERSION/build" || "mkdir wxWidgets-$WXVERSION/build"
+    cd "wxWidgets-$WXVERSION/build"
     ../configure --disable-shared --prefix="$prefix" --with-opengl --enable-unicode CC="gcc $arch_flags" CXX="g++ $arch_flags"
     make -s
     make -s install
@@ -78,35 +94,48 @@ mkdir Survex/Aven.app/Contents/MacOS
 mkdir Survex/Aven.app/Contents/Resources
 cp lib/Info.plist Survex/Aven.app/Contents
 printf APPLAVEN > Survex/Aven.app/Contents/PkgInfo
-cp -r $D/share/survex/* Survex/Aven.app/Contents/Resources/
+cp -r "$D"/share/survex/* Survex/Aven.app/Contents/Resources/
 # FIXME: Generate Survex/Aven.app/Resources/Aven.icns
 mv Survex/aven Survex/Aven.app/Contents/MacOS/
-rm -f Survex/share/survex/aven.txf
+rm -f Survex/share/survex/unifont.pixelfont
 rm -rf Survex/share/survex/icons
 
 size=`du -s Survex|sed 's/[^0-9].*//'`
 # Allow 1000 extra sectors for various overheads (500 wasn't enough).
-sectors=`expr 1000 + $size`
+sectors=`expr 1000 + "$size"`
 # Partition needs to be at least 4M and sectors are 512 bytes.
-if test $sectors -lt 8192 ; then
+if test "$sectors" -lt 8192 ; then
   sectors=8192
 fi
 echo "Creating new blank image survex-macosx.dmg of $sectors sectors"
 # This creates the diskimage file and initialises it as an HFS+ volume.
-hdiutil create -sectors $sectors survex-macosx -layout NONE -fs HFS+ -volname Survex
+hdiutil create -sectors "$sectors" survex-macosx -layout NONE -fs HFS+ -volname Survex
 
 echo "Presenting image to the filesystems for mounting."
 # This will mount the image onto the Desktop.
-# Get the name of the device we mounted it on...
-dev=`hdid survex-macosx.dmg|tail -1|sed 's!/dev/\([!-~]*\).*!\1!;'`
-echo "Mounted on device $dev, copying files into image."
-ditto -rsrcFork Survex /Volumes/Survex/Survex
-ditto lib/INSTALL.OSX /Volumes/Survex/INSTALL
+# Get the name of the device it is mounted on and the mount point.
+
+# man hdiutil says:
+# "The output of [hdiutil] attach has been stable since OS X 10.0 (though it
+# was called hdid(8) then) and is intended to be program-readable.  It consists
+# of the /dev node, a tab, a content hint (if applicable), another tab, and a
+# mount point (if any filesystems were mounted)."
+#
+# In reality, it seems there are also some spaces before each tab character.
+hdid_output=`hdid survex-macosx.dmg|tail -1`
+echo "Last line of hdid output was: $hdid_output"
+dev=`echo "$hdid_output"|sed 's!/dev/\([^	 ]*\).*!\1!'`
+mount_point=`echo "$hdid_output"|sed 's!.*[	 ]!!'`
+
+echo "Device $dev mounted on $mount_point, copying files into image."
+ditto -rsrcFork Survex "$mount_point/Survex"
+ditto lib/INSTALL.OSX "$mount_point/INSTALL"
+
 echo "Detaching image."
-hdiutil detach $dev
+hdiutil detach "$dev"
 
 version=`sed 's/.*AM_INIT_AUTOMAKE([^,]*, *\([0-9.]*\).*/\1/p;d' configure.in`
-file=survex-macosx-`echo $version`.dmg
+file=survex-macosx-$version.dmg
 echo "Compressing image file survex-macosx.dmg to $file"
 # This needs MacOS X 10.1 or above for unpacking - change UDZO to UDCO to allow
 # the dmg to be unpacked on 10.0 as well:
