@@ -4,7 +4,7 @@
 //  Main class for Aven.
 //
 //  Copyright (C) 2001 Mark R. Shinwell.
-//  Copyright (C) 2002,2003,2004,2005,2006 Olly Betts
+//  Copyright (C) 2002,2003,2004,2005,2006,2011 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -43,6 +43,8 @@
 #include <wx/display.h>
 #endif
 
+bool double_buffered = false;
+
 static const struct option long_opts[] = {
     /* const char *name; int has_arg (0 no_argument, 1 required_*, 2 optional_*); int *flag; int val; */
     {"survey", required_argument, 0, 's'},
@@ -55,10 +57,10 @@ static const struct option long_opts[] = {
 #define short_opts "s:p"
 
 static struct help_msg help[] = {
-    /*			     <-- */
-    {HLP_ENCODELONG(0),          "only load the sub-survey with this prefix"},
-    {HLP_ENCODELONG(1),          "print and exit (requires a 3d file)"},
-    {0, 0}
+    /*				<-- */
+    {HLP_ENCODELONG(0),       /*only load the sub-survey with this prefix*/199, 0},
+    {HLP_ENCODELONG(1),       /*print and exit (requires a 3d file)*/119, 0},
+    {0, 0, 0}
 };
 
 #ifdef __WXMSW__
@@ -76,7 +78,7 @@ Aven::Aven() :
 
 Aven::~Aven()
 {
-    if (m_pageSetupData) delete m_pageSetupData;
+    delete m_pageSetupData;
 }
 
 static int getopt_first_response = 0;
@@ -84,10 +86,8 @@ static int getopt_first_response = 0;
 #ifdef __WXMSW__
 bool Aven::Initialize(int& my_argc, wxChar **my_argv)
 {
-    // Call msg_init() and start processing the command line first so that
-    // we can respond to --help and --version even without an X display.
-    // However, wxWidgets passes us wxChars, which may be wide characters
-    // and cmdline wants UTF-8 so we need to convert.
+    // wxWidgets passes us wxChars, which may be wide characters but cmdline
+    // wants UTF-8 so we need to convert.
     char *utf8_argv[my_argc + 1];
     for (int i = 0; i < my_argc; ++i){
 	utf8_argv[i] = strdup(wxString(my_argv[i]).mb_str());
@@ -96,10 +96,10 @@ bool Aven::Initialize(int& my_argc, wxChar **my_argv)
 
     msg_init(utf8_argv);
     select_charset(CHARSET_UTF8);
-    /* Want --version and a decent --help output, which cmdline does for us.
+    /* Want --version and decent --help output, which cmdline does for us.
      * wxCmdLine is much less good.
      */
-    cmdline_set_syntax_message("[3d file]", NULL);
+    cmdline_set_syntax_message(/*[SURVEY_FILE]*/269, 0, NULL);
     cmdline_init(my_argc, utf8_argv, short_opts, long_opts, NULL, help, 0, 1);
     getopt_first_response = cmdline_getopt();
     return wxApp::Initialize(my_argc, my_argv);
@@ -111,11 +111,6 @@ static char ** real_argv;
 int main(int argc, char **argv) 
 {
 #ifdef __WXMAC__
-    // Tell wxMac which the About and Quit menu items are so they can be put
-    // where MacOS users expect them to be.
-    wxApp::s_macAboutMenuItemId = menu_HELP_ABOUT;
-    wxApp::s_macExitMenuItemId = menu_FILE_QUIT;
-
     // MacOS passes a magic -psn_XXXX command line argument in argv[1] which
     // wx ignores for us, but in wxApp::Initialize() which hasn't been
     // called yet.  So we need to remove it ourselves.
@@ -128,15 +123,16 @@ int main(int argc, char **argv)
     // we can respond to --help and --version even without an X display.
     msg_init(argv);
     select_charset(CHARSET_UTF8);
-    /* Want --version and a decent --help output, which cmdline does for us.
+    /* Want --version and decent --help output, which cmdline does for us.
      * wxCmdLine is much less good.
      */
-    cmdline_set_syntax_message("[3d file]", NULL);
+    cmdline_set_syntax_message(/*[SURVEY_FILE]*/269, 0, NULL);
     cmdline_init(argc, argv, short_opts, long_opts, NULL, help, 0, 1);
     getopt_first_response = cmdline_getopt();
 
     real_argv = argv;
 
+#if wxUSE_UNICODE
     wxWCharBuffer buf(wxConvFileName->cMB2WX(argv[0]));
     wxChar * wargv[2];
     if (buf) {
@@ -148,6 +144,10 @@ int main(int argc, char **argv)
     wargv[1] = NULL;
     int wargc = 1;
     return wxEntry(wargc, wargv);
+#else
+    char dummy_argv[2] = { argv[0], NULL };
+    return wxEntry(1, dummy_argv);
+#endif
 }
 #endif
 
@@ -163,7 +163,7 @@ bool Aven::OnInit()
 	wxString msg_lang_str(msg_lang, wxConvUTF8);
 	const char *lang = msg_lang2 ? msg_lang2 : msg_lang;
 	wxString lang_str(lang, wxConvUTF8);
-	loc->Init(msg_lang_str, lang_str, msg_lang_str, TRUE, TRUE);
+	loc->Init(msg_lang_str, lang_str, msg_lang_str, true, true);
 	// The existence of the wxLocale object is enough - no need to keep a
 	// pointer to it!
     }
@@ -202,11 +202,19 @@ bool Aven::OnInit()
 	}
     }
 
-    if (!InitGLVisual(NULL)) {
-	wxString m;
-	m.Printf(wmsg(/*This version of %s requires OpenGL to work, but it isn't available*/405), APP_NAME);
-	wxMessageBox(m, APP_NAME, wxOK | wxCENTRE | wxICON_EXCLAMATION);
-	exit(1);
+    // Use a double-buffered visual if available, as it will give much smoother
+    // animation.
+    double_buffered = true;
+    int wx_gl_attribs[] = { WX_GL_RGBA, WX_GL_DOUBLEBUFFER, 0 };
+    if (!InitGLVisual(wx_gl_attribs)) {
+	int wx_gl_attribs_no_db[] = { WX_GL_RGBA, 0 };
+	if (!InitGLVisual(wx_gl_attribs_no_db)) {
+	    wxString m;
+	    m.Printf(wmsg(/*This version of %s requires OpenGL to work, but it isn't available*/405), APP_NAME);
+	    wxMessageBox(m, APP_NAME, wxOK | wxCENTRE | wxICON_EXCLAMATION);
+	    exit(1);
+	}
+	double_buffered = false;
     }
 
     wxImage::AddHandler(new wxPNGHandler);
