@@ -1,6 +1,6 @@
 /* avenprcore.cc
  * Printer independent parts of Survex printer drivers
- * Copyright (C) 1993-2002,2004,2005,2006,2010 Olly Betts
+ * Copyright (C) 1993-2002,2004,2005,2006,2010,2011 Olly Betts
  * Copyright (C) 2004 Philip Underwood
  *
  * This program is free software; you can redistribute it and/or modify
@@ -79,7 +79,7 @@ layout::pages_required() {
     double paper_centre_x, paper_centre_y;
 
     double allow = 21.0;
-    if (!Raw) allow += (view == EXTELEV ? 30.0 : 40.0);
+    if (!Raw) allow += 30.0;
     double Sc = 1000 / Scale;
     image_dx = (xMax - xMin) * Sc;
     if (PaperWidth > 0.0) {
@@ -224,7 +224,7 @@ layout::pick_scale(int x, int y)
       Sc_x = (x * PaperWidth - 19.0) / (xMax - xMin);
    if (PaperDepth > 0.0 && yMax > yMin) {
       double allow = 21.0;
-      if (!Raw) allow += (view == EXTELEV ? 30.0 : 40.0);
+      if (!Raw) allow += 30.0;
       Sc_y = (y * PaperDepth - allow) / (yMax - yMin);
    }
 
@@ -260,12 +260,10 @@ void print_all(MainFrm *m_parent, layout *l, device *pri) {
 
     /* note down so we can switch to printer charset */
     msg166 = msgPerm(/*Page %d of %d*/166);
-    select_charset(Charset());
+    old_charset = select_charset(CHARSET_ISO_8859_1);
 
-    /* used in printer's native charset in footer */
     l->footer = msgPerm(/*Survey `%s'   Page %d (of %d)   Processed on %s*/167);
 
-    old_charset = select_charset(CHARSET_ISO_8859_1);
     cPagesPrinted = 0;
     page = state = 0;
     p = l->szPages;
