@@ -1,6 +1,6 @@
 /* cavern.c
  * SURVEX Cave surveying software: data reduction main and related functions
- * Copyright (C) 1991-2003,2004,2005,2010 Olly Betts
+ * Copyright (C) 1991-2003,2004,2005,2010,2011 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #endif
 
 #include <limits.h>
+#include <stdlib.h>
 #include <time.h>
 
 #include "cavern.h"
@@ -104,6 +105,7 @@ static const struct option long_opts[] = {
    {"no-auxiliary-files", no_argument, 0, 's'},
    {"warnings-are-errors", no_argument, 0, 'w'},
    {"log", no_argument, 0, 1},
+   {"3d-version", required_argument, 0, 'v'},
 #if OS_WIN32
    {"pause", no_argument, 0, 2},
 #endif
@@ -112,19 +114,20 @@ static const struct option long_opts[] = {
    {0, 0, 0, 0}
 };
 
-#define short_opts "pao:qswz:"
+#define short_opts "pao:qsv:wz:"
 
 /* TRANSLATE extract help messages to message file */
 static struct help_msg help[] = {
 /*				<-- */
-   {HLP_ENCODELONG(0),		"display percentage progress"},
-   {HLP_ENCODELONG(2),		"set location for output files"},
-   {HLP_ENCODELONG(3),		"only show brief summary (-qq for errors only)"},
-   {HLP_ENCODELONG(4),		"do not create .err file"},
-   {HLP_ENCODELONG(5),		"turn warnings into errors"},
-   {HLP_ENCODELONG(6),		"log output to .log file"},
+   {HLP_ENCODELONG(0),	      /*display percentage progress*/161, 0},
+   {HLP_ENCODELONG(2),	      /*set location for output files*/162, 0},
+   {HLP_ENCODELONG(3),	      /*only show brief summary (-qq for errors only)*/163, 0},
+   {HLP_ENCODELONG(4),	      /*do not create .err file*/164, 0},
+   {HLP_ENCODELONG(5),	      /*turn warnings into errors*/165, 0},
+   {HLP_ENCODELONG(6),	      /*log output to .log file*/170, 0},
+   {HLP_ENCODELONG(7),	      /*specify the 3d file format version to output*/171, 0},
  /*{'z',			"set optimizations for network reduction"},*/
-   {0, 0}
+   {0, 0, 0}
 };
 
 /* atexit functions */
@@ -228,6 +231,14 @@ main(int argc, char **argv)
        case 's':
 	 fSuppress = 1;
 	 break;
+       case 'v': {
+	 int v = atoi(optarg);
+	 if (v < IMG_VERSION_MIN || v > IMG_VERSION_MAX)
+	    fatalerror(/*3d file format versions %d to %d supported*/88,
+		       IMG_VERSION_MIN, IMG_VERSION_MAX);
+	 img_output_version = v;
+	 break;
+       }
        case 'w':
 	 f_warnings_are_errors = 1;
 	 break;
@@ -366,7 +377,7 @@ main(int argc, char **argv)
    }
    if (msg_warnings || msg_errors) {
       if (msg_errors || (f_warnings_are_errors && msg_warnings)) {
-	 printf(msg(/*There were %d warning(s) and %d non-fatal error(s) - no output files produced.*/113),
+	 printf(msg(/*There were %d warning(s) and %d error(s) - no output files produced.*/113),
 		msg_warnings, msg_errors);
 	 putnl();
 	 return EXIT_FAILURE;
@@ -378,13 +389,14 @@ main(int argc, char **argv)
 }
 
 static void
-do_range(int d, int msg1, int msg2, int msg3)
+do_range(int d, int msgno)
 {
-   printf(msg(msg1), max[d] - min[d]);
-   fprint_prefix(stdout, pfxHi[d]);
-   printf(msg(msg2), max[d]);
-   fprint_prefix(stdout, pfxLo[d]);
-   printf(msg(msg3), min[d]);
+   // sprint_prefix uses a single buffer, so to report two stations in one
+   // message we need to make a temporary copy of the string for one of them.
+   char * pfx_hi = osstrdup(sprint_prefix(pfxHi[d]));
+   char * pfx_lo = sprint_prefix(pfxLo[d]);
+   printf(msg(msgno), max[d] - min[d], pfx_hi, max[d], pfx_lo, min[d]);
+   osfree(pfx_hi);
    putnl();
 }
 
@@ -434,12 +446,9 @@ do_stats(void)
 
    /* If there's no underground survey, we've no ranges */
    if (pfxHi[0]) {
-      do_range(2, /*Vertical range = %4.2fm (from */135,
-	       /* at %4.2fm to */136, /* at %4.2fm)*/137);
-      do_range(1, /*North-South range = %4.2fm (from */148,
-	       /* at %4.2fm to */196, /* at %4.2fm)*/197);
-      do_range(0, /*East-West range = %4.2fm (from */149,
-	       /* at %4.2fm to */196, /* at %4.2fm)*/197);
+      do_range(2, /*Vertical range = %4.2fm (from %s at %4.2fm to %s at %4.2fm)*/135);
+      do_range(1, /*North-South range = %4.2fm (from %s at %4.2fm to %s at %4.2fm)*/136);
+      do_range(0, /*East-West range = %4.2fm from %s at %4.2fm to %s at %4.2fm)*/137);
    }
 
    print_node_stats();
