@@ -1,6 +1,6 @@
 /* extend.c
  * Produce an extended elevation
- * Copyright (C) 1995-2002,2005,2010 Olly Betts
+ * Copyright (C) 1995-2002,2005,2010,2011 Olly Betts
  * Copyright (C) 2004,2005 John Pybus
  *
  * This program is free software; you can redistribute it and/or modify
@@ -440,9 +440,8 @@ static const struct option long_opts[] = {
 
 static struct help_msg help[] = {
 /*				<-- */
-   {HLP_ENCODELONG(0),          "only load the sub-survey with this prefix"},
-   {HLP_ENCODELONG(1),          "apply specifications from the named file"},
-   {0, 0}
+   {HLP_ENCODELONG(0),        /*only load the sub-survey with this prefix*/199, 0},
+   {0, 0, 0}
 };
 
 int
@@ -462,7 +461,7 @@ main(int argc, char **argv)
 
    msg_init(argv);
 
-   cmdline_set_syntax_message("INPUT_3D_FILE [OUTPUT_3D_FILE]", NULL);
+   cmdline_set_syntax_message(/*INPUT_3D_FILE [OUTPUT_3D_FILE]*/267, 0, NULL);
    cmdline_init(argc, argv, short_opts, long_opts, NULL, help, 1, 2);
    while (1) {
       int opt = cmdline_getopt();
