@@ -4,7 +4,7 @@
 //  Core drawing code for Aven.
 //
 //  Copyright (C) 2000-2001,2002,2005 Mark R. Shinwell.
-//  Copyright (C) 2001-2004,2005,2006,2007,2010 Olly Betts
+//  Copyright (C) 2001-2004,2005,2006,2007,2010,2011 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -43,8 +43,6 @@ using namespace std;
 class MainFrm;
 class traverse;
 
-extern const int NUM_DEPTH_COLOURS;
-
 // Mac OS X headers pollute the global namespace with generic names like
 // "class Point", which clashes with our "class Point".  So for __WXMAC__
 // put our class in a namespace and define Point as a macro.
@@ -93,7 +91,8 @@ enum {
     COLOUR_BY_NONE,
     COLOUR_BY_DEPTH,
     COLOUR_BY_DATE,
-    COLOUR_BY_ERROR
+    COLOUR_BY_ERROR,
+    COLOUR_BY_LIMIT_ // Leave this last.
 };
 
 enum {
@@ -110,18 +109,22 @@ class GfxCore : public GLACanvas {
 	LIST_COMPASS,
 	LIST_CLINO,
 	LIST_CLINO_BACK,
-	LIST_DEPTHBAR,
-	LIST_DATEBAR,
-	LIST_ERRORBAR,
+	LIST_SCALE_BAR,
+	LIST_DEPTH_KEY,
+	LIST_DATE_KEY,
+	LIST_ERROR_KEY,
 	LIST_UNDERGROUND_LEGS,
 	LIST_TUBES,
 	LIST_SURFACE_LEGS,
 	LIST_BLOBS,
 	LIST_CROSSES,
 	LIST_GRID,
-	LIST_SHADOW
+	LIST_SHADOW,
+	LIST_LIMIT_ // Leave this last.
     } drawing_list;
 
+    static const int NUM_COLOUR_BANDS = 13;
+
 public:
     typedef enum {
 	CURSOR_DEFAULT,
@@ -149,13 +152,11 @@ private:
     bool m_Legs;
     bool m_Names;
     bool m_Scalebar;
-    bool m_Depthbar;
+    bool m_ColourKey;
     bool m_OverlappingNames;
     bool m_Compass;
     bool m_Clino;
     bool m_Tubes;
-    int m_XSize;
-    int m_YSize;
     int m_ColourBy;
 
     bool m_HaveData;
@@ -190,12 +191,21 @@ private:
     double next_mark_time;
     double this_mark_total;
 
-    MovieMaker * mpeg;
+    MovieMaker * movie;
 
     cursor current_cursor;
 
+    // The legends for each entry in the colour key.
+    wxString key_legends[NUM_COLOUR_BANDS];
+
+    wxPoint key_lowerleft[COLOUR_BY_LIMIT_];
+
     void PlaceVertexWithColour(const Vector3 &v, Double factor = 1.0);
+    void PlaceVertexWithColour(const Vector3 & v, GLint tex_x, GLint tex_y,
+			       Double factor);
+    void SetDepthColour(Double z, Double factor);
     void PlaceVertexWithDepthColour(const Vector3 & v, Double factor = 1.0);
+    void PlaceVertexWithDepthColour(const Vector3 & v, GLint tex_x, GLint tex_y, Double factor);
 
     void SetColourFromDate(int date, Double factor);
     void SetColourFromError(double E, Double factor);
@@ -219,10 +229,11 @@ private:
     void TryToFreeArrays();
     void FirstShow();
 
-    void DrawScalebar();
-    void DrawDepthbar();
-    void DrawDatebar();
-    void DrawErrorbar();
+    void DrawScaleBar();
+    void DrawColourKey(int num_bands, const wxString & other);
+    void DrawDepthKey();
+    void DrawDateKey();
+    void DrawErrorKey();
     void DrawCompass();
     void DrawClino();
     void DrawClinoBack();
@@ -246,13 +257,13 @@ private:
     void ToggleFlag(bool* flag, int update = UPDATE_NONE);
 
     GLAPen& GetPen(int band) const {
-	assert(band >= 0 && band < NUM_DEPTH_COLOURS);
+	assert(band >= 0 && band < NUM_COLOUR_BANDS);
 	return m_Pens[band];
     }
 
-    GLAPen& GetSurfacePen() const { return m_Pens[NUM_DEPTH_COLOURS]; }
+    GLAPen& GetSurfacePen() const { return m_Pens[NUM_COLOUR_BANDS]; }
 
-    int GetNumDepthBands() const { return NUM_DEPTH_COLOURS; }
+    int GetNumColourBands() const { return NUM_COLOUR_BANDS; }
 
     void DrawShadowedBoundingBox();
     void DrawBoundingBox();
@@ -313,6 +324,7 @@ public:
     bool PointWithinCompass(wxPoint point) const;
     bool PointWithinClino(wxPoint point) const;
     bool PointWithinScaleBar(wxPoint point) const;
+    bool PointWithinColourKey(wxPoint point) const;
 
     void SetCompassFromPoint(wxPoint point);
     void SetClinoFromPoint(wxPoint point);
@@ -333,6 +345,7 @@ public:
 
     void SetViewTo(Double xmin, Double xmax, Double ymin, Double ymax, Double zmin, Double zmax);
 
+    double GetCompassValue() const { return m_PanAngle; }
     bool ShowingPlan() const;
     bool ShowingElevation() const;
     bool ShowingMeasuringLine() const;
@@ -344,8 +357,8 @@ public:
     bool IsRotating() const { return m_Rotating; }
     bool HasData() const { return m_DoneFirstShow && m_HaveData; }
     bool HasDepth() const;
-    bool HasRangeOfDates() const;
     bool HasErrorInformation() const;
+    bool HasDateInformation() const;
 
     double GetScale() const { return m_Scale; }
     void SetScale(Double scale);
@@ -364,7 +377,7 @@ public:
     bool ShowingUndergroundLegs() const { return m_Legs; }
     bool ShowingSurfaceLegs() const { return m_Surface; }
 
-    bool ShowingDepthBar() const { return m_Depthbar; }
+    bool ShowingColourKey() const { return m_ColourKey; }
     bool ShowingScaleBar() const { return m_Scalebar; }
 
     bool ShowingEntrances() const { return m_Entrances; }
@@ -381,8 +394,14 @@ public:
     void ToggleSurfaceLegs() {
 	ToggleFlag(&m_Surface, UPDATE_BLOBS_AND_CROSSES);
     }
-    void ToggleCompass() { ToggleFlag(&m_Compass); }
-    void ToggleClino() { ToggleFlag(&m_Clino); }
+    void ToggleCompass() {
+	ToggleFlag(&m_Compass);
+	InvalidateList(LIST_SCALE_BAR);
+    }
+    void ToggleClino() {
+	ToggleFlag(&m_Clino);
+	InvalidateList(LIST_SCALE_BAR);
+    }
     void ToggleScaleBar() { ToggleFlag(&m_Scalebar); }
     void ToggleEntrances() { ToggleFlag(&m_Entrances, UPDATE_BLOBS); }
     void ToggleFixedPts() { ToggleFlag(&m_FixedPts, UPDATE_BLOBS); }
@@ -391,8 +410,12 @@ public:
     void ToggleCrosses() { ToggleFlag(&m_Crosses); }
     void ToggleStationNames() { ToggleFlag(&m_Names); }
     void ToggleOverlappingNames() { ToggleFlag(&m_OverlappingNames); }
-    void ToggleDepthBar() { ToggleFlag(&m_Depthbar); }
-    void ToggleMetric() { ToggleFlag(&m_Metric); InvalidateList(LIST_DEPTHBAR); }
+    void ToggleColourKey() { ToggleFlag(&m_ColourKey); }
+    void ToggleMetric() {
+	ToggleFlag(&m_Metric);
+	InvalidateList(LIST_DEPTH_KEY);
+	InvalidateList(LIST_SCALE_BAR);
+    }
     void ToggleDegrees() { ToggleFlag(&m_Degrees); }
     void ToggleTubes() { ToggleFlag(&m_Tubes); }
     void TogglePerspective() { GLACanvas::TogglePerspective(); ForceRefresh(); }
@@ -452,7 +475,15 @@ public:
 		 const wxString &datestamp);
     void OnExport(const wxString &filename, const wxString &title);
     void SetCursor(GfxCore::cursor new_cursor);
+    bool MeasuringLineActive() const;
 
+    bool HandleRClick(wxPoint point);
+
+    void InvalidateAllLists() {
+	for (int i = 0; i < LIST_LIMIT_; ++i) {
+	    InvalidateList(i);
+	}
+    }
 private:
     DECLARE_EVENT_TABLE()
 };
