@@ -4,7 +4,7 @@
 //  OpenGL implementation for the GLA abstraction layer.
 //
 //  Copyright (C) 2002-2003,2005 Mark R. Shinwell
-//  Copyright (C) 2003,2004,2005,2006,2007,2010 Olly Betts
+//  Copyright (C) 2003,2004,2005,2006,2007,2010,2011 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -65,23 +65,6 @@
 #define GL_ALIASED_POINT_SIZE_RANGE 0x846D
 #endif
 
-#ifndef USE_FNT
-// Some WIN32 stupidity which causes mingw to fail to link for some reason;
-// doing this probably means we can't safely use atexit() - see the comments in
-// glut.h if you can take the full horror...
-#define GLUT_DISABLE_ATEXIT_HACK
-// For glutBitmapLength()
-#define GLUT_API_VERSION 4
-#ifdef __APPLE__
-#include <OpenGL/glut.h>
-#else
-#include <GL/glut.h>
-#endif
-#ifdef FREEGLUT
-#include <GL/freeglut_ext.h>
-#endif
-#endif
-
 using namespace std;
 
 const int BLOB_DIAMETER = 5;
@@ -104,7 +87,11 @@ string GetGLSystemDescription()
     info += (const char*)glGetString(GL_VENDOR);
     info += '\n';
     info += (const char*)glGetString(GL_RENDERER);
+#if defined __WXGTK__ || defined __WXX11__ || defined __WXMOTIF__
+    info += string_format("\nGLX %0.1f\n", wxGLCanvas::GetGLXVersion() * 0.1);
+#else
     info += '\n';
+#endif
 
     GLint red, green, blue;
     glGetIntegerv(GL_RED_BITS, &red);
@@ -133,6 +120,12 @@ string GetGLSystemDescription()
 			      point_size_range[0], point_size_range[1]);
     }
 
+    info += "\nDouble buffered: ";
+    if (double_buffered)
+	info += "true";
+    else
+	info += "false";
+
     const GLubyte* gl_extensions = glGetString(GL_EXTENSIONS);
     if (*gl_extensions) {
 	info += '\n';
@@ -162,10 +155,6 @@ GLAPen::GLAPen()
     components[0] = components[1] = components[2] = 0.0;
 }
 
-GLAPen::~GLAPen()
-{
-}
-
 void GLAPen::SetColour(double red, double green, double blue)
 {
     components[0] = red;
@@ -190,9 +179,9 @@ double GLAPen::GetBlue() const
 
 void GLAPen::Interpolate(const GLAPen& pen, double how_far)
 {
-    components[0] = how_far * (pen.GetRed() - components[0]) + components[0];
-    components[1] = how_far * (pen.GetGreen() - components[1]) + components[1];
-    components[2] = how_far * (pen.GetBlue() - components[2]) + components[2];
+    components[0] += how_far * (pen.GetRed() - components[0]);
+    components[1] += how_far * (pen.GetGreen() - components[1]);
+    components[2] += how_far * (pen.GetBlue() - components[2]);
 }
 
 struct ColourTriple {
@@ -234,15 +223,11 @@ void GLAList::InvalidateList() {
 //  GLACanvas
 //
 
-#ifndef USE_FNT
-void* const GLACanvas::m_Font = GLUT_BITMAP_HELVETICA_10;
-const int GLACanvas::m_FontSize = 10;
-#endif
-
 // Pass wxWANTS_CHARS so that the window gets cursor keys on MS Windows.
 GLACanvas::GLACanvas(wxWindow* parent, int id)
     : wxGLCanvas(parent, id, wxDefaultPosition, wxDefaultSize, wxWANTS_CHARS),
-      m_Translation(), blob_method(UNKNOWN), cross_method(UNKNOWN)
+      m_Translation(), blob_method(UNKNOWN), cross_method(UNKNOWN),
+      x_size(0), y_size(0)
 {
     // Constructor.
 
@@ -258,12 +243,6 @@ GLACanvas::GLACanvas(wxWindow* parent, int id)
     m_Fog = false;
     m_AntiAlias = false;
     list_flags = 0;
-
-#ifndef USE_FNT
-    int argc = 1;
-    char * argv[] = { (char*)"aven", NULL };
-    glutInit(&argc, argv);
-#endif
 }
 
 GLACanvas::~GLACanvas()
@@ -278,6 +257,9 @@ GLACanvas::~GLACanvas()
 
 void GLACanvas::FirstShow()
 {
+    // Update our record of the client area size and centre.
+    GetClientSize(&x_size, &y_size);
+
     SetCurrent();
     opengl_initialised = true;
     save_hints = false;
@@ -347,15 +329,15 @@ void GLACanvas::FirstShow()
     glPixelStorei(GL_PACK_ALIGNMENT, 1); // For screengrabs and movies.
     CHECK_GL_ERROR("FirstShow", "glPixelStorei GL_PACK_ALIGNMENT");
 
-#ifdef USE_FNT
     // Load font
     wxString path = wmsg_cfgpth();
     path += wxCONFIG_PATH_SEPARATOR;
-    path += wxT("aven.txf");
-    // FIXME: This should really use fn_str() - currently we probably can't
-    // save to a Unicode path on wxmsw.
-    m_Font.load(path.mb_str());
-#endif
+    path += wxT("unifont.pixelfont");
+    if (!m_Font.load(path)) {
+	// FIXME: do something better.
+	fprintf(stderr, "Couldn't load font.\n");
+	exit(1);
+    }
 
     if (blob_method == UNKNOWN) {
 	// Check if we can use GL_POINTS to plot blobs at stations.
@@ -471,6 +453,27 @@ void GLACanvas::SetScale(Double scale)
     }
 }
 
+void GLACanvas::OnSize(wxSizeEvent & event)
+{
+    wxSize size = event.GetSize();
+
+    unsigned int mask = 0;
+    if (size.GetWidth() != x_size) mask |= INVALIDATE_ON_X_RESIZE;
+    if (size.GetHeight() != y_size) mask |= INVALIDATE_ON_Y_RESIZE;
+    if (mask) {
+	vector<GLAList>::iterator i;
+	for (i = drawing_lists.begin(); i != drawing_lists.end(); ++i) {
+	    if (*i && i->test_flag(mask)) i->InvalidateList();
+	}
+
+	x_size = size.GetWidth();
+	y_size = size.GetHeight();
+    }
+
+    // This apparently is (or at least was) needed for Mac OS X.
+    wxGLCanvas::OnSize(event);
+}
+
 void GLACanvas::AddTranslationScreenCoordinates(int dx, int dy)
 {
     // Translate the data by a given amount, specified in screen coordinates.
@@ -669,7 +672,7 @@ void GLACanvas::SetDataTransform()
     // Get axes the correct way around (z upwards, y into screen)
     glRotated(-90.0, 1.0, 0.0, 0.0);
     CHECK_GL_ERROR("SetDataTransform", "glRotated");
-    glRotated(m_Tilt, 1.0, 0.0, 0.0);
+    glRotated(-m_Tilt, 1.0, 0.0, 0.0);
     CHECK_GL_ERROR("SetDataTransform", "glRotated");
     glRotated(m_Pan, 0.0, 0.0, 1.0);
     CHECK_GL_ERROR("SetDataTransform", "CopyToOpenGL");
@@ -794,9 +797,12 @@ void GLACanvas::FinishDrawing()
 {
     // Complete a redraw operation.
 
-//    glFlush();
-//    CHECK_GL_ERROR("FinishDrawing", "glFlush");
-    SwapBuffers();
+    if (double_buffered) {
+	SwapBuffers();
+    } else {
+	glFlush();
+	CHECK_GL_ERROR("FinishDrawing", "glFlush");
+    }
 }
 
 void GLACanvas::DrawList(unsigned int l)
@@ -911,66 +917,21 @@ void GLACanvas::SetColour(gla_colour colour)
 void GLACanvas::DrawText(glaCoord x, glaCoord y, glaCoord z, const wxString& str)
 {
     // Draw a text string on the current buffer in the current font.
-#ifdef USE_FNT
-    GLdouble X, Y, Z;
-    if (!gluProject(x, y, z, modelview_matrix, projection_matrix, viewport,
-		    &X, &Y, &Z)) return;
-    // Only draw text which is in front of the viewer.
-    if (Z > 0) DrawIndicatorText((int)X, (int)Y, str);
-#else
     glRasterPos3d(x, y, z);
     CHECK_GL_ERROR("DrawText", "glRasterPos3d");
-
-// glutBitmapString() useless for Unicode strings.
-//#ifdef FREEGLUT
-#if 0
-    glutBitmapString(m_Font, (const unsigned char *)str.c_str());
-    CHECK_GL_ERROR("DrawText", "glutBitmapString");
-#else
-    for (size_t pos = 0; pos < str.length(); pos++) {
-        glutBitmapCharacter(m_Font, int((unsigned char)str[pos]));
-        CHECK_GL_ERROR("DrawText", "glutBitmapCharacter");
-    }
-#endif
-#endif
+    m_Font.write_string(str.data(), str.size());
 }
 
 void GLACanvas::DrawIndicatorText(int x, int y, const wxString& str)
 {
-#ifdef USE_FNT
-    glPushAttrib(GL_ENABLE_BIT);
-    glDisable(GL_ALPHA_TEST);
-    glEnable(GL_BLEND);
-    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-    glEnable(GL_TEXTURE_2D);
-    glDisable(GL_DEPTH_TEST);
-    m_Font.puts(x, y, str.data(), str.size());
-    glPopAttrib();
-#else
-    DrawText(x, y, 0.0, str);
-#endif
+    glRasterPos2d(x, y);
+    CHECK_GL_ERROR("DrawIndicatorText", "glRasterPos2d");
+    m_Font.write_string(str.data(), str.size());
 }
 
 void GLACanvas::GetTextExtent(const wxString& str, int * x_ext, int * y_ext)
 {
-#ifdef USE_FNT
-    m_Font.getTextExtent(str.c_str(), x_ext, y_ext);
-#else
-    if (x_ext) {
-// glutBitmapLength() useless for Unicode strings.
-#if 0
-	*x_ext = glutBitmapLength(m_Font, (const unsigned char *)str.c_str());
-	CHECK_GL_ERROR("GetTextExtent", "glutBitmapLength");
-#else
-	*x_ext = 0;
-	for (size_t pos = 0; pos < str.length(); pos++) {
-	    x_ext += glutBitmapWidth(m_Font, int((unsigned char)str[pos]));
-	    CHECK_GL_ERROR("GetTextExtent", "glutBitmapWidth");
-	}
-#endif
-    }
-    if (y_ext) *y_ext = m_FontSize + 2;
-#endif
+    m_Font.get_text_extent(str.data(), str.size(), x_ext, y_ext);
 }
 
 void GLACanvas::BeginQuadrilaterals()
@@ -1073,6 +1034,18 @@ void GLACanvas::PlaceVertex(glaCoord x, glaCoord y, glaCoord z)
     glVertex3d(x, y, z);
 }
 
+void GLACanvas::PlaceVertex(glaCoord x, glaCoord y, glaCoord z,
+			    glaTexCoord tex_x, glaTexCoord tex_y)
+{
+    // Place a vertex for the current object being drawn.
+
+#ifdef GLA_DEBUG
+    m_Vertices++;
+#endif
+    glTexCoord2i(tex_x, tex_y);
+    glVertex3d(x, y, z);
+}
+
 void GLACanvas::PlaceIndicatorVertex(glaCoord x, glaCoord y)
 {
     // Place a vertex for the current indicator object being drawn.
@@ -1500,3 +1473,18 @@ bool GLACanvas::CheckVisualFidelity(const unsigned char * target) const
     glReadPixels(width / 2 - 3, height / 2 - 4, 8, 8, GL_RGB, GL_UNSIGNED_BYTE, (GLvoid *)pixels);
     return (memcmp(pixels, target, sizeof(pixels)) == 0);
 }
+
+void GLACanvas::ReadPixels(int width, int height, unsigned char * buf) const
+{
+    glReadPixels(0, 0, width, height, GL_RGB, GL_UNSIGNED_BYTE, (GLvoid *)buf);
+}
+
+void GLACanvas::PolygonOffset(bool on) const
+{
+    if (on) {
+	glPolygonOffset(1.0, 1.0);
+	glEnable(GL_POLYGON_OFFSET_FILL);
+    } else {
+	glDisable(GL_POLYGON_OFFSET_FILL);
+    }
+}
