@@ -4,7 +4,7 @@
 //  Header file for the GLA abstraction layer.
 //
 //  Copyright (C) 2002 Mark R. Shinwell.
-//  Copyright (C) 2003,2004,2005,2006,2007 Olly Betts
+//  Copyright (C) 2003,2004,2005,2006,2007,2011 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -21,9 +21,6 @@
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
-// Use texture mapped fonts (lots faster, at least with hardware 3d)
-#define USE_FNT
-
 #include <string>
 #include <vector>
 
@@ -33,9 +30,7 @@ using namespace std;
 #include "aventypes.h"
 #include "vector3.h"
 
-#ifdef USE_FNT
-#include "fnt.h"
-#endif
+#include "glbitmapfont.h"
 
 class GfxCore;
 
@@ -45,6 +40,8 @@ string GetGLSystemDescription();
 
 typedef Double glaCoord;
 
+typedef GLint glaTexCoord;
+
 // Colours for drawing.  Don't reorder these!
 enum gla_colour {
     col_BLACK = 0,
@@ -70,7 +67,6 @@ class GLAPen {
 
 public:
     GLAPen();
-    ~GLAPen();
 
     void SetColour(double red, double green, double blue); // arguments in range 0 to 1.0
     void Interpolate(const GLAPen&, double how_far);
@@ -80,9 +76,6 @@ public:
     double GetBlue() const;
 };
 
-const unsigned int INVALIDATE_ON_SCALE = 1;
-const unsigned int NEVER_CACHE = 2;
-
 class GLAList {
     GLuint gl_list;
     unsigned int flags;
@@ -113,12 +106,7 @@ class GLACanvas : public wxGLCanvas {
     Double m_Scale;
     Vector3 m_Translation;
 
-#ifdef USE_FNT
-    fntTexFont m_Font;
-#else
-    static void * const m_Font;
-    static const int m_FontSize;
-#endif
+    BitmapFont m_Font;
 
     GLUquadric* m_Quadric;
 
@@ -135,7 +123,17 @@ class GLACanvas : public wxGLCanvas {
     int blob_method;
     int cross_method;
 
+    int x_size;
+    int y_size;
+
     vector<GLAList> drawing_lists;
+
+    enum {
+	INVALIDATE_ON_SCALE = 1,
+	INVALIDATE_ON_X_RESIZE = 2,
+	INVALIDATE_ON_Y_RESIZE = 4,
+	NEVER_CACHE = 8
+    };
     mutable unsigned int list_flags;
 
     wxString vendor, renderer;
@@ -201,10 +199,15 @@ public:
     void DrawCross(glaCoord x, glaCoord y, glaCoord z);
     void DrawRing(glaCoord x, glaCoord y);
 
+    void PlaceVertex(const Vector3 & v, glaTexCoord tex_x, glaTexCoord tex_y) {
+	PlaceVertex(v.GetX(), v.GetY(), v.GetZ(), tex_x, tex_y);
+    }
     void PlaceVertex(const Vector3 & v) {
 	PlaceVertex(v.GetX(), v.GetY(), v.GetZ());
     }
     void PlaceVertex(glaCoord x, glaCoord y, glaCoord z);
+    void PlaceVertex(glaCoord x, glaCoord y, glaCoord z,
+		     glaTexCoord tex_x, glaTexCoord tex_y);
     void PlaceIndicatorVertex(glaCoord x, glaCoord y);
 
     void PlaceNormal(const Vector3 &v);
@@ -234,11 +237,7 @@ public:
     bool Transform(const Vector3 & v, double* x_out, double* y_out, double* z_out) const;
     void ReverseTransform(Double x, Double y, double* x_out, double* y_out, double* z_out) const;
 
-#ifdef USE_FNT
-    int GetFontSize() const { return m_Font.getFontSize(); }
-#else
-    int GetFontSize() const { return m_FontSize; }
-#endif
+    int GetFontSize() const { return m_Font.get_font_size(); }
 
     void ToggleSmoothShading();
     bool GetSmoothShading() const { return m_SmoothShading; }
@@ -258,4 +257,15 @@ public:
     bool GetAntiAlias() const { return m_AntiAlias; }
 
     bool SaveScreenshot(const wxString & fnm, int type) const;
+
+    void ReadPixels(int width, int height, unsigned char * buf) const;
+
+    void PolygonOffset(bool on) const;
+
+    int GetXSize() const { list_flags |= INVALIDATE_ON_X_RESIZE; return x_size; }
+    int GetYSize() const { list_flags |= INVALIDATE_ON_Y_RESIZE; return y_size; }
+
+    void OnSize(wxSizeEvent & event);
+
+    glaCoord GetVolumeDiameter() const { return m_VolumeDiameter; }
 };
