@@ -4,7 +4,7 @@
 //  Main frame handling for Aven.
 //
 //  Copyright (C) 2000-2002,2005,2006 Mark R. Shinwell
-//  Copyright (C) 2001-2003,2004,2005,2006,2010 Olly Betts
+//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -80,7 +80,7 @@ class EditMarkDlg : public wxDialog {
     wxTextCtrl * angle, * tilt_angle, * scale, * time;
 public:
     EditMarkDlg(wxWindow* parent, const PresentationMark & p)
-	: wxDialog(parent, 500, wxString(wxT("Edit Waypoint")))
+	: wxDialog(parent, 500, wmsg(/*Edit Waypoint*/404))
     {
 	easting = new wxTextCtrl(this, 601, wxString::Format(wxT("%.3f"), p.GetX()));
 	northing = new wxTextCtrl(this, 602, wxString::Format(wxT("%.3f"), p.GetY()));
@@ -107,31 +107,31 @@ public:
 	wxBoxSizer* vert = new wxBoxSizer(wxVERTICAL);
 	vert->Add(coords, 0, wxALL, 8);
 	wxBoxSizer * r2 = new wxBoxSizer(wxHORIZONTAL);
-	r2->Add(new wxStaticText(this, 614, wxT("Bearing: ")), 0, wxALIGN_CENTRE_VERTICAL);
+	r2->Add(new wxStaticText(this, 614, wmsg(/*Bearing*/259) + wxT(": ")), 0, wxALIGN_CENTRE_VERTICAL);
 	r2->Add(angle);
 	vert->Add(r2, 0, wxALL, 8);
 	wxBoxSizer * r3 = new wxBoxSizer(wxHORIZONTAL);
-	r3->Add(new wxStaticText(this, 615, wxT("Elevation: ")), 0, wxALIGN_CENTRE_VERTICAL);
+	r3->Add(new wxStaticText(this, 615, wmsg(/*Elevation*/118) + wxT(": ")), 0, wxALIGN_CENTRE_VERTICAL);
 	r3->Add(tilt_angle);
 	vert->Add(r3, 0, wxALL, 8);
 	wxBoxSizer * r4 = new wxBoxSizer(wxHORIZONTAL);
-	r4->Add(new wxStaticText(this, 616, wxT("Scale: ")), 0, wxALIGN_CENTRE_VERTICAL);
+	r4->Add(new wxStaticText(this, 616, wmsg(/*Scale*/154) + wxT(": ")), 0, wxALIGN_CENTRE_VERTICAL);
 	r4->Add(scale);
-	r4->Add(new wxStaticText(this, 617, wxT(" (unused in perspective view)")),
+	r4->Add(new wxStaticText(this, 617, wmsg(/* (unused in perspective view)*/278)),
 		0, wxALIGN_CENTRE_VERTICAL);
 	vert->Add(r4, 0, wxALL, 8);
 
 	wxBoxSizer * r5 = new wxBoxSizer(wxHORIZONTAL);
-	r5->Add(new wxStaticText(this, 616, wxT("Time: ")), 0, wxALIGN_CENTRE_VERTICAL);
+	r5->Add(new wxStaticText(this, 616, wmsg(/*Time: */279)), 0, wxALIGN_CENTRE_VERTICAL);
 	r5->Add(time);
-	r5->Add(new wxStaticText(this, 617, wxT(" secs (0 = auto; *6 = 6 times auto)")),
+	r5->Add(new wxStaticText(this, 617, wmsg(/* secs (0 = auto; *6 = 6 times auto)*/282)),
 		0, wxALIGN_CENTRE_VERTICAL);
 	vert->Add(r5, 0, wxALL, 8);
 
 	wxBoxSizer * buttons = new wxBoxSizer(wxHORIZONTAL);
-	wxButton* cancel = new wxButton(this, wxID_CANCEL, wxT("Cancel"));
+	wxButton* cancel = new wxButton(this, wxID_CANCEL);
 	buttons->Add(cancel, 0, wxALL, 8);
-	wxButton* ok = new wxButton(this, wxID_OK, wxT("OK"));
+	wxButton* ok = new wxButton(this, wxID_OK);
 	ok->SetDefault();
 	buttons->Add(ok, 0, wxALL, 8);
 	vert->Add(buttons, 0, wxALL|wxALIGN_RIGHT);
@@ -151,7 +151,7 @@ public:
 	t = atof(tilt_angle->GetValue().mb_str());
 	s = atof(scale->GetValue().mb_str());
 	wxString str = time->GetValue();
-	if (str[0u] == '*') str[0u] = '-';
+	if (!str.empty() && str[0u] == '*') str[0u] = '-';
 	T = atof(str.mb_str());
 	return PresentationMark(v, a, t, s, T);
     }
@@ -250,7 +250,7 @@ class AvenPresList : public wxListCtrl {
 	void OnChar(wxKeyEvent& event) {
 	    switch (event.GetKeyCode()) {
 		case WXK_INSERT:
-		    if (event.m_controlDown) {
+		    if (event.GetModifiers() == wxMOD_CONTROL) {
 			if (current_item != -1 &&
 			    size_t(current_item) < entries.size()) {
 			    AddMark(current_item, entries[current_item]);
@@ -448,17 +448,17 @@ END_EVENT_TABLE()
 BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_TEXT(textctrl_FIND, MainFrm::OnFind)
     EVT_TEXT_ENTER(textctrl_FIND, MainFrm::OnGotoFound)
-    EVT_MENU(button_FIND, MainFrm::OnGotoFound)
+    EVT_MENU(wxID_FIND, MainFrm::OnGotoFound)
     EVT_MENU(button_HIDE, MainFrm::OnHide)
     EVT_UPDATE_UI(button_HIDE, MainFrm::OnHideUpdate)
 
-    EVT_MENU(menu_FILE_OPEN, MainFrm::OnOpen)
-    EVT_MENU(menu_FILE_PRINT, MainFrm::OnPrint)
+    EVT_MENU(wxID_OPEN, MainFrm::OnOpen)
+    EVT_MENU(wxID_PRINT, MainFrm::OnPrint)
     EVT_MENU(menu_FILE_PAGE_SETUP, MainFrm::OnPageSetup)
     EVT_MENU(menu_FILE_SCREENSHOT, MainFrm::OnScreenshot)
-//    EVT_MENU(menu_FILE_PREFERENCES, MainFrm::OnFilePreferences)
+//    EVT_MENU(wxID_PREFERENCES, MainFrm::OnFilePreferences)
     EVT_MENU(menu_FILE_EXPORT, MainFrm::OnExport)
-    EVT_MENU(menu_FILE_QUIT, MainFrm::OnQuit)
+    EVT_MENU(wxID_EXIT, MainFrm::OnQuit)
     EVT_MENU_RANGE(wxID_FILE1, wxID_FILE9, MainFrm::OnMRUFile)
 
     EVT_MENU(menu_PRES_NEW, MainFrm::OnPresNew)
@@ -473,7 +473,7 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_MENU(menu_PRES_FF, MainFrm::OnPresFF)
     EVT_MENU(menu_PRES_FFF, MainFrm::OnPresFFF)
     EVT_MENU(menu_PRES_PAUSE, MainFrm::OnPresPause)
-    EVT_MENU(menu_PRES_STOP, MainFrm::OnPresStop)
+    EVT_MENU(wxID_STOP, MainFrm::OnPresStop)
     EVT_MENU(menu_PRES_EXPORT_MOVIE, MainFrm::OnPresExportMovie)
 
     EVT_UPDATE_UI(menu_PRES_NEW, MainFrm::OnPresNewUpdate)
@@ -488,7 +488,7 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_UPDATE_UI(menu_PRES_FF, MainFrm::OnPresFFUpdate)
     EVT_UPDATE_UI(menu_PRES_FFF, MainFrm::OnPresFFFUpdate)
     EVT_UPDATE_UI(menu_PRES_PAUSE, MainFrm::OnPresPauseUpdate)
-    EVT_UPDATE_UI(menu_PRES_STOP, MainFrm::OnPresStopUpdate)
+    EVT_UPDATE_UI(wxID_STOP, MainFrm::OnPresStopUpdate)
     EVT_UPDATE_UI(menu_PRES_EXPORT_MOVIE, MainFrm::OnPresExportMovieUpdate)
 
     EVT_CLOSE(MainFrm::OnClose)
@@ -512,8 +512,8 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_MENU(menu_ORIENT_ELEVATION, MainFrm::OnElevation)
     EVT_MENU(menu_ORIENT_HIGHER_VP, MainFrm::OnHigherViewpoint)
     EVT_MENU(menu_ORIENT_LOWER_VP, MainFrm::OnLowerViewpoint)
-    EVT_MENU(menu_ORIENT_ZOOM_IN, MainFrm::OnZoomIn)
-    EVT_MENU(menu_ORIENT_ZOOM_OUT, MainFrm::OnZoomOut)
+    EVT_MENU(wxID_ZOOM_IN, MainFrm::OnZoomIn)
+    EVT_MENU(wxID_ZOOM_OUT, MainFrm::OnZoomOut)
     EVT_MENU(menu_ORIENT_DEFAULTS, MainFrm::OnDefaults)
     EVT_MENU(menu_VIEW_SHOW_LEGS, MainFrm::OnShowSurveyLegs)
     EVT_MENU(menu_VIEW_SHOW_CROSSES, MainFrm::OnShowCrosses)
@@ -537,16 +537,16 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_MENU(menu_VIEW_SHOW_TUBES, MainFrm::OnToggleTubes)
     EVT_MENU(menu_IND_COMPASS, MainFrm::OnViewCompass)
     EVT_MENU(menu_IND_CLINO, MainFrm::OnViewClino)
-    EVT_MENU(menu_IND_DEPTH_BAR, MainFrm::OnToggleDepthbar)
+    EVT_MENU(menu_IND_COLOUR_KEY, MainFrm::OnToggleColourKey)
     EVT_MENU(menu_IND_SCALE_BAR, MainFrm::OnToggleScalebar)
     EVT_MENU(menu_CTL_SIDE_PANEL, MainFrm::OnViewSidePanel)
     EVT_MENU(menu_CTL_METRIC, MainFrm::OnToggleMetric)
     EVT_MENU(menu_CTL_DEGREES, MainFrm::OnToggleDegrees)
     EVT_MENU(menu_CTL_REVERSE, MainFrm::OnReverseControls)
     EVT_MENU(menu_CTL_CANCEL_DIST_LINE, MainFrm::OnCancelDistLine)
-    EVT_MENU(menu_HELP_ABOUT, MainFrm::OnAbout)
+    EVT_MENU(wxID_ABOUT, MainFrm::OnAbout)
 
-    EVT_UPDATE_UI(menu_FILE_PRINT, MainFrm::OnPrintUpdate)
+    EVT_UPDATE_UI(wxID_PRINT, MainFrm::OnPrintUpdate)
     EVT_UPDATE_UI(menu_FILE_SCREENSHOT, MainFrm::OnScreenshotUpdate)
     EVT_UPDATE_UI(menu_FILE_EXPORT, MainFrm::OnExportUpdate)
     EVT_UPDATE_UI(menu_ROTATION_TOGGLE, MainFrm::OnToggleRotationUpdate)
@@ -567,8 +567,8 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_UPDATE_UI(menu_ORIENT_ELEVATION, MainFrm::OnElevationUpdate)
     EVT_UPDATE_UI(menu_ORIENT_HIGHER_VP, MainFrm::OnHigherViewpointUpdate)
     EVT_UPDATE_UI(menu_ORIENT_LOWER_VP, MainFrm::OnLowerViewpointUpdate)
-    EVT_UPDATE_UI(menu_ORIENT_ZOOM_IN, MainFrm::OnZoomInUpdate)
-    EVT_UPDATE_UI(menu_ORIENT_ZOOM_OUT, MainFrm::OnZoomOutUpdate)
+    EVT_UPDATE_UI(wxID_ZOOM_IN, MainFrm::OnZoomInUpdate)
+    EVT_UPDATE_UI(wxID_ZOOM_OUT, MainFrm::OnZoomOutUpdate)
     EVT_UPDATE_UI(menu_ORIENT_DEFAULTS, MainFrm::OnDefaultsUpdate)
     EVT_UPDATE_UI(menu_VIEW_SHOW_LEGS, MainFrm::OnShowSurveyLegsUpdate)
     EVT_UPDATE_UI(menu_VIEW_SHOW_CROSSES, MainFrm::OnShowCrossesUpdate)
@@ -592,7 +592,7 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_UPDATE_UI(menu_VIEW_SHOW_TUBES, MainFrm::OnToggleTubesUpdate)
     EVT_UPDATE_UI(menu_IND_COMPASS, MainFrm::OnViewCompassUpdate)
     EVT_UPDATE_UI(menu_IND_CLINO, MainFrm::OnViewClinoUpdate)
-    EVT_UPDATE_UI(menu_IND_DEPTH_BAR, MainFrm::OnToggleDepthbarUpdate)
+    EVT_UPDATE_UI(menu_IND_COLOUR_KEY, MainFrm::OnToggleColourKeyUpdate)
     EVT_UPDATE_UI(menu_IND_SCALE_BAR, MainFrm::OnToggleScalebarUpdate)
     EVT_UPDATE_UI(menu_CTL_INDICATORS, MainFrm::OnIndicatorsUpdate)
     EVT_UPDATE_UI(menu_CTL_SIDE_PANEL, MainFrm::OnViewSidePanelUpdate)
@@ -652,11 +652,11 @@ DnDFile::OnDropFiles(wxCoord, wxCoord, const wxArrayString &filenames)
 
     if (filenames.GetCount() != 1) {
 	wxGetApp().ReportError(wmsg(/*You may only view one 3d file at a time.*/336));
-	return FALSE;
+	return false;
     }
 
     m_Parent->OpenFile(filenames[0]);
-    return TRUE;
+    return true;
 }
 #endif
 
@@ -703,144 +703,143 @@ MainFrm::MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size)
 #endif
 }
 
-MainFrm::~MainFrm()
-{
-}
-
 void MainFrm::CreateMenuBar()
 {
     // Create the menus and the menu bar.
 
     wxMenu* filemenu = new wxMenu;
-    filemenu->Append(menu_FILE_OPEN, GetTabMsg(/*@Open...##Ctrl+O*/220));
+    // wxID_OPEN stock label lacks the ellipses
+    filemenu->Append(wxID_OPEN, wmsg(/*&Open...\tCtrl+O*/220));
     filemenu->AppendSeparator();
-    filemenu->Append(menu_FILE_PRINT, GetTabMsg(/*@Print...##Ctrl+P*/380));
-    filemenu->Append(menu_FILE_PAGE_SETUP, GetTabMsg(/*P@age Setup...*/381));
+    // wxID_PRINT stock label lacks the ellipses
+    filemenu->Append(wxID_PRINT, wmsg(/*&Print...\tCtrl+P*/380));
+    filemenu->Append(menu_FILE_PAGE_SETUP, wmsg(/*P&age Setup...*/381));
     filemenu->AppendSeparator();
-    filemenu->Append(menu_FILE_SCREENSHOT, GetTabMsg(/*@Screenshot...*/201));
-    filemenu->Append(menu_FILE_EXPORT, GetTabMsg(/*@Export as...*/382));
+    filemenu->Append(menu_FILE_SCREENSHOT, wmsg(/*&Screenshot...*/201));
+    filemenu->Append(menu_FILE_EXPORT, wmsg(/*&Export as...*/382));
 #ifndef __WXMAC__
     // On wxMac the "Quit" menu item will be moved elsewhere, so we suppress
     // this separator.
     filemenu->AppendSeparator();
 #endif
-    filemenu->Append(menu_FILE_QUIT, GetTabMsg(/*@Quit##Ctrl+Q*/221));
+    filemenu->Append(wxID_EXIT);
 
     m_history.UseMenu(filemenu);
     m_history.Load(*wxConfigBase::Get());
 
     wxMenu* rotmenu = new wxMenu;
-    rotmenu->AppendCheckItem(menu_ROTATION_TOGGLE, GetTabMsg(/*@Auto-Rotate##Space*/231));
+    rotmenu->AppendCheckItem(menu_ROTATION_TOGGLE, wmsg(/*&Auto-Rotate\tSpace*/231));
     rotmenu->AppendSeparator();
-    rotmenu->Append(menu_ROTATION_SPEED_UP, GetTabMsg(/*Speed @Up*/232));
-    rotmenu->Append(menu_ROTATION_SLOW_DOWN, GetTabMsg(/*Slow @Down*/233));
+    rotmenu->Append(menu_ROTATION_SPEED_UP, wmsg(/*Speed &Up*/232));
+    rotmenu->Append(menu_ROTATION_SLOW_DOWN, wmsg(/*Slow &Down*/233));
     rotmenu->AppendSeparator();
-    rotmenu->Append(menu_ROTATION_REVERSE, GetTabMsg(/*@Reverse Direction*/234));
+    rotmenu->Append(menu_ROTATION_REVERSE, wmsg(/*&Reverse Direction*/234));
     rotmenu->AppendSeparator();
-    rotmenu->Append(menu_ROTATION_STEP_CCW, GetTabMsg(/*Step Once @Anticlockwise*/235));
-    rotmenu->Append(menu_ROTATION_STEP_CW, GetTabMsg(/*Step Once @Clockwise*/236));
+    rotmenu->Append(menu_ROTATION_STEP_CCW, wmsg(/*Step Once &Anticlockwise*/235));
+    rotmenu->Append(menu_ROTATION_STEP_CW, wmsg(/*Step Once &Clockwise*/236));
 
     wxMenu* orientmenu = new wxMenu;
-    orientmenu->Append(menu_ORIENT_MOVE_NORTH, GetTabMsg(/*View @North*/240));
-    orientmenu->Append(menu_ORIENT_MOVE_EAST, GetTabMsg(/*View @East*/241));
-    orientmenu->Append(menu_ORIENT_MOVE_SOUTH, GetTabMsg(/*View @South*/242));
-    orientmenu->Append(menu_ORIENT_MOVE_WEST, GetTabMsg(/*View @West*/243));
+    orientmenu->Append(menu_ORIENT_MOVE_NORTH, wmsg(/*View &North*/240));
+    orientmenu->Append(menu_ORIENT_MOVE_EAST, wmsg(/*View &East*/241));
+    orientmenu->Append(menu_ORIENT_MOVE_SOUTH, wmsg(/*View &South*/242));
+    orientmenu->Append(menu_ORIENT_MOVE_WEST, wmsg(/*View &West*/243));
     orientmenu->AppendSeparator();
-    orientmenu->Append(menu_ORIENT_SHIFT_LEFT, GetTabMsg(/*Shift Survey @Left*/244));
-    orientmenu->Append(menu_ORIENT_SHIFT_RIGHT, GetTabMsg(/*Shift Survey @Right*/245));
-    orientmenu->Append(menu_ORIENT_SHIFT_UP, GetTabMsg(/*Shift Survey @Up*/246));
-    orientmenu->Append(menu_ORIENT_SHIFT_DOWN, GetTabMsg(/*Shift Survey @Down*/247));
+    orientmenu->Append(menu_ORIENT_SHIFT_LEFT, wmsg(/*Shift Survey &Left*/244));
+    orientmenu->Append(menu_ORIENT_SHIFT_RIGHT, wmsg(/*Shift Survey &Right*/245));
+    orientmenu->Append(menu_ORIENT_SHIFT_UP, wmsg(/*Shift Survey &Up*/246));
+    orientmenu->Append(menu_ORIENT_SHIFT_DOWN, wmsg(/*Shift Survey &Down*/247));
     orientmenu->AppendSeparator();
-    orientmenu->Append(menu_ORIENT_PLAN, GetTabMsg(/*@Plan View*/248));
-    orientmenu->Append(menu_ORIENT_ELEVATION, GetTabMsg(/*Ele@vation*/249));
+    orientmenu->Append(menu_ORIENT_PLAN, wmsg(/*&Plan View*/248));
+    orientmenu->Append(menu_ORIENT_ELEVATION, wmsg(/*Ele&vation*/249));
     orientmenu->AppendSeparator();
-    orientmenu->Append(menu_ORIENT_HIGHER_VP, GetTabMsg(/*@Higher Viewpoint*/250));
-    orientmenu->Append(menu_ORIENT_LOWER_VP, GetTabMsg(/*L@ower Viewpoint*/251));
+    orientmenu->Append(menu_ORIENT_HIGHER_VP, wmsg(/*&Higher Viewpoint*/250));
+    orientmenu->Append(menu_ORIENT_LOWER_VP, wmsg(/*L&ower Viewpoint*/251));
     orientmenu->AppendSeparator();
-    orientmenu->Append(menu_ORIENT_ZOOM_IN, GetTabMsg(/*@Zoom In##]*/252));
-    orientmenu->Append(menu_ORIENT_ZOOM_OUT, GetTabMsg(/*Zoo@m Out##[*/253));
+    // Default labels for wxID_ZOOM_IN and wxID_ZOOM_OUT don't have accels.
+    orientmenu->Append(wxID_ZOOM_IN, wmsg(/*&Zoom In\t]*/252));
+    orientmenu->Append(wxID_ZOOM_OUT, wmsg(/*Zoo&m Out\t[*/253));
     orientmenu->AppendSeparator();
-    orientmenu->Append(menu_ORIENT_DEFAULTS, GetTabMsg(/*Restore De@fault View*/254));
+    orientmenu->Append(menu_ORIENT_DEFAULTS, wmsg(/*Restore De&fault View*/254));
 
     wxMenu* presmenu = new wxMenu;
-    presmenu->Append(menu_PRES_NEW, GetTabMsg(/*@New Presentation*/311));
-    presmenu->Append(menu_PRES_OPEN, GetTabMsg(/*@Open Presentation...*/312));
-    presmenu->Append(menu_PRES_SAVE, GetTabMsg(/*@Save Presentation*/313));
-    presmenu->Append(menu_PRES_SAVE_AS, GetTabMsg(/*Save Presentation @As...*/314));
+    presmenu->Append(menu_PRES_NEW, wmsg(/*&New Presentation*/311));
+    presmenu->Append(menu_PRES_OPEN, wmsg(/*&Open Presentation...*/312));
+    presmenu->Append(menu_PRES_SAVE, wmsg(/*&Save Presentation*/313));
+    presmenu->Append(menu_PRES_SAVE_AS, wmsg(/*Save Presentation &As...*/314));
     presmenu->AppendSeparator();
-    presmenu->Append(menu_PRES_MARK, GetTabMsg(/*@Mark*/315));
-    presmenu->Append(menu_PRES_PLAY, GetTabMsg(/*@Play*/316));
-    presmenu->Append(menu_PRES_EXPORT_MOVIE, GetTabMsg(/*@Export as Movie...*/317));
+    presmenu->Append(menu_PRES_MARK, wmsg(/*&Mark*/315));
+    presmenu->Append(menu_PRES_PLAY, wmsg(/*&Play*/316));
+    presmenu->Append(menu_PRES_EXPORT_MOVIE, wmsg(/*&Export as Movie...*/317));
 
     wxMenu* viewmenu = new wxMenu;
 #ifndef PREFDLG
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_NAMES, GetTabMsg(/*Station @Names##Ctrl+N*/270));
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_TUBES, GetTabMsg(/*Passage @Tubes*/346));
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_CROSSES, GetTabMsg(/*@Crosses##Ctrl+X*/271));
-    viewmenu->AppendCheckItem(menu_VIEW_GRID, GetTabMsg(/*@Grid##Ctrl+G*/297));
-    viewmenu->AppendCheckItem(menu_VIEW_BOUNDING_BOX, GetTabMsg(/*@Bounding Box##Ctrl+B*/318));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_NAMES, wmsg(/*Station &Names\tCtrl+N*/270));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_TUBES, wmsg(/*Passage &Tubes*/346));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_CROSSES, wmsg(/*&Crosses\tCtrl+X*/271));
+    viewmenu->AppendCheckItem(menu_VIEW_GRID, wmsg(/*&Grid\tCtrl+G*/297));
+    viewmenu->AppendCheckItem(menu_VIEW_BOUNDING_BOX, wmsg(/*&Bounding Box\tCtrl+B*/318));
     viewmenu->AppendSeparator();
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_LEGS, GetTabMsg(/*@Underground Survey Legs##Ctrl+L*/272));
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_SURFACE, GetTabMsg(/*@Surface Survey Legs##Ctrl+F*/291));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_LEGS, wmsg(/*&Underground Survey Legs\tCtrl+L*/272));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_SURFACE, wmsg(/*&Surface Survey Legs\tCtrl+F*/291));
     viewmenu->AppendSeparator();
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_OVERLAPPING_NAMES, GetTabMsg(/*@Overlapping Names*/273));
-    viewmenu->AppendCheckItem(menu_VIEW_COLOUR_BY_DEPTH, GetTabMsg(/*Colour by @Depth*/292));
-    viewmenu->AppendCheckItem(menu_VIEW_COLOUR_BY_DATE, GetTabMsg(/*Colour by D@ate*/293));
-    viewmenu->AppendCheckItem(menu_VIEW_COLOUR_BY_ERROR, GetTabMsg(/*Colour by E@rror*/289));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_OVERLAPPING_NAMES, wmsg(/*&Overlapping Names*/273));
+    viewmenu->AppendCheckItem(menu_VIEW_COLOUR_BY_DEPTH, wmsg(/*Colour by &Depth*/292));
+    viewmenu->AppendCheckItem(menu_VIEW_COLOUR_BY_DATE, wmsg(/*Colour by D&ate*/293));
+    viewmenu->AppendCheckItem(menu_VIEW_COLOUR_BY_ERROR, wmsg(/*Colour by E&rror*/289));
     viewmenu->AppendSeparator();
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_ENTRANCES, GetTabMsg(/*Highlight @Entrances*/294));
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_FIXED_PTS, GetTabMsg(/*Highlight @Fixed Points*/295));
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_EXPORTED_PTS, GetTabMsg(/*Highlight E@xported Points*/296));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_ENTRANCES, wmsg(/*Highlight &Entrances*/294));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_FIXED_PTS, wmsg(/*Highlight &Fixed Points*/295));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_EXPORTED_PTS, wmsg(/*Highlight E&xported Points*/296));
     viewmenu->AppendSeparator();
 #else
-    viewmenu-> Append(menu_VIEW_CANCEL_DIST_LINE, GetTabMsg(/*@Cancel Measuring Line##Escape*/281));
+    viewmenu-> Append(menu_VIEW_CANCEL_DIST_LINE, wmsg(/*&Cancel Measuring Line\tEscape*/281));
 #endif
-    viewmenu->AppendCheckItem(menu_VIEW_PERSPECTIVE, GetTabMsg(/*@Perspective*/237));
-// FIXME: enable this    viewmenu->AppendCheckItem(menu_VIEW_SMOOTH_SHADING, GetTabMsg(/*@Smooth Shading*/?!?);
-    viewmenu->AppendCheckItem(menu_VIEW_TEXTURED, GetTabMsg(/*Textured @Walls*/238));
-    viewmenu->AppendCheckItem(menu_VIEW_FOG, GetTabMsg(/*Fade @Distant Objects*/239));
-    viewmenu->AppendCheckItem(menu_VIEW_SMOOTH_LINES, GetTabMsg(/*@Smoothed Survey Legs*/298));
+    viewmenu->AppendCheckItem(menu_VIEW_PERSPECTIVE, wmsg(/*&Perspective*/237));
+// FIXME: enable this    viewmenu->AppendCheckItem(menu_VIEW_SMOOTH_SHADING, wmsg(/*&Smooth Shading*/?!?);
+    viewmenu->AppendCheckItem(menu_VIEW_TEXTURED, wmsg(/*Textured &Walls*/238));
+    viewmenu->AppendCheckItem(menu_VIEW_FOG, wmsg(/*Fade &Distant Objects*/239));
+    viewmenu->AppendCheckItem(menu_VIEW_SMOOTH_LINES, wmsg(/*&Smoothed Survey Legs*/298));
     viewmenu->AppendSeparator();
-    viewmenu->AppendCheckItem(menu_VIEW_FULLSCREEN, GetTabMsg(/*@Full Screen Mode##F11*/356));
+    viewmenu->AppendCheckItem(menu_VIEW_FULLSCREEN, wmsg(/*&Full Screen Mode\tF11*/356));
 #ifdef PREFDLG
     viewmenu->AppendSeparator();
-    viewmenu-> Append(menu_VIEW_PREFERENCES, GetTabMsg(/*@Preferences...*/347));
+    viewmenu-> Append(wxID_PREFERENCES, wmsg(/*&Preferences...*/347));
 #endif
 
 #ifndef PREFDLG
     wxMenu* ctlmenu = new wxMenu;
-    ctlmenu->AppendCheckItem(menu_CTL_REVERSE, GetTabMsg(/*@Reverse Sense##Ctrl+R*/280));
+    ctlmenu->AppendCheckItem(menu_CTL_REVERSE, wmsg(/*&Reverse Sense\tCtrl+R*/280));
     ctlmenu->AppendSeparator();
-    ctlmenu->Append(menu_CTL_CANCEL_DIST_LINE, GetTabMsg(/*@Cancel Measuring Line##Escape*/281));
+    ctlmenu->Append(menu_CTL_CANCEL_DIST_LINE, wmsg(/*&Cancel Measuring Line\tEscape*/281));
     ctlmenu->AppendSeparator();
     wxMenu* indmenu = new wxMenu;
-    indmenu->AppendCheckItem(menu_IND_COMPASS, GetTabMsg(/*@Compass*/274));
-    indmenu->AppendCheckItem(menu_IND_CLINO, GetTabMsg(/*C@linometer*/275));
-    indmenu->AppendCheckItem(menu_IND_DEPTH_BAR, GetTabMsg(/*@Depth Bar*/276));
-    indmenu->AppendCheckItem(menu_IND_SCALE_BAR, GetTabMsg(/*@Scale Bar*/277));
-    ctlmenu->Append(menu_CTL_INDICATORS, GetTabMsg(/*@Indicators*/299), indmenu);
-    ctlmenu->AppendCheckItem(menu_CTL_SIDE_PANEL, GetTabMsg(/*@Side Panel*/337));
+    indmenu->AppendCheckItem(menu_IND_COMPASS, wmsg(/*&Compass*/274));
+    indmenu->AppendCheckItem(menu_IND_CLINO, wmsg(/*C&linometer*/275));
+    indmenu->AppendCheckItem(menu_IND_COLOUR_KEY, wmsg(/*Colour &Key*/276));
+    indmenu->AppendCheckItem(menu_IND_SCALE_BAR, wmsg(/*&Scale Bar*/277));
+    ctlmenu->Append(menu_CTL_INDICATORS, wmsg(/*&Indicators*/299), indmenu);
+    ctlmenu->AppendCheckItem(menu_CTL_SIDE_PANEL, wmsg(/*&Side Panel*/337));
     ctlmenu->AppendSeparator();
-    ctlmenu->AppendCheckItem(menu_CTL_METRIC, GetTabMsg(/*@Metric*/342));
-    ctlmenu->AppendCheckItem(menu_CTL_DEGREES, GetTabMsg(/*@Degrees*/343));
+    ctlmenu->AppendCheckItem(menu_CTL_METRIC, wmsg(/*&Metric*/342));
+    ctlmenu->AppendCheckItem(menu_CTL_DEGREES, wmsg(/*&Degrees*/343));
 #endif
 
     wxMenu* helpmenu = new wxMenu;
-    helpmenu->Append(menu_HELP_ABOUT, GetTabMsg(/*@About...*/290));
+    helpmenu->Append(wxID_ABOUT);
 
     wxMenuBar* menubar = new wxMenuBar();
-    menubar->Append(filemenu, GetTabMsg(/*@File*/210));
-    menubar->Append(rotmenu, GetTabMsg(/*@Rotation*/211));
-    menubar->Append(orientmenu, GetTabMsg(/*@Orientation*/212));
-    menubar->Append(viewmenu, GetTabMsg(/*@View*/213));
+    menubar->Append(filemenu, wmsg(/*&File*/210));
+    menubar->Append(rotmenu, wmsg(/*&Rotation*/211));
+    menubar->Append(orientmenu, wmsg(/*&Orientation*/212));
+    menubar->Append(viewmenu, wmsg(/*&View*/213));
 #ifndef PREFDLG
-    menubar->Append(ctlmenu, GetTabMsg(/*@Controls*/214));
+    menubar->Append(ctlmenu, wmsg(/*&Controls*/214));
 #endif
-    menubar->Append(presmenu, GetTabMsg(/*@Presentation*/216));
+    menubar->Append(presmenu, wmsg(/*&Presentation*/216));
 #ifndef __WXMAC__
     // On wxMac the "About" menu item will be moved elsewhere, so we suppress
     // this menu since it will then be empty.
-    menubar->Append(helpmenu, GetTabMsg(/*@Help*/215));
+    menubar->Append(helpmenu, wmsg(/*&Help*/215));
 #endif
     SetMenuBar(menubar);
 }
@@ -859,7 +858,7 @@ void MainFrm::CreateToolBar()
 #endif
 
     // FIXME: TRANSLATE tooltips
-    toolbar->AddTool(menu_FILE_OPEN, wxT("Open"), TOOLBAR_BITMAP("open"), wxT("Open a 3D file for viewing"));
+    toolbar->AddTool(wxID_OPEN, wxT("Open"), TOOLBAR_BITMAP("open"), wxT("Open a survey file for viewing"));
     toolbar->AddTool(menu_PRES_OPEN, wxT("Open presentation"), TOOLBAR_BITMAP("open-pres"), wxT("Open a presentation"));
     toolbar->AddSeparator();
     toolbar->AddCheckTool(menu_ROTATION_TOGGLE, wxT("Toggle rotation"), TOOLBAR_BITMAP("rotation"), wxNullBitmap, wxT("Toggle rotation"));
@@ -884,13 +883,13 @@ void MainFrm::CreateToolBar()
     toolbar->AddCheckTool(menu_PRES_PLAY, wxT("Go"), TOOLBAR_BITMAP("pres-go"), wxNullBitmap, wxT("Play"));
     toolbar->AddCheckTool(menu_PRES_FF, wxT("FF"), TOOLBAR_BITMAP("pres-ff"), wxNullBitmap, wxT("Fast Forward"));
     toolbar->AddCheckTool(menu_PRES_FFF, wxT("Very FF"), TOOLBAR_BITMAP("pres-fff"), wxNullBitmap, wxT("Very Fast Forward"));
-    toolbar->AddTool(menu_PRES_STOP, wxT("Stop"), TOOLBAR_BITMAP("pres-stop"), wxT("Stop"));
+    toolbar->AddTool(wxID_STOP, wxT("Stop"), TOOLBAR_BITMAP("pres-stop"), wxT("Stop"));
 
     toolbar->AddSeparator();
     m_FindBox = new wxTextCtrl(toolbar, textctrl_FIND, wxString(), wxDefaultPosition,
 			       wxDefaultSize, wxTE_PROCESS_ENTER);
     toolbar->AddControl(m_FindBox);
-    toolbar->AddTool(button_FIND, TOOLBAR_BITMAP("find"),
+    toolbar->AddTool(wxID_FIND, TOOLBAR_BITMAP("find"),
 		     wmsg(/*Find*/332)/*"Search for station name"*/);
     toolbar->AddTool(button_HIDE, TOOLBAR_BITMAP("hideresults"),
 		     wmsg(/*Hide*/333)/*"Hide search results"*/);
@@ -998,7 +997,7 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
     Double depthmax = -DBL_MAX;
 
     m_DateMin = INT_MAX;
-    int datemax = 0;
+    int datemax = -1;
     complete_dateinfo = true;
 
     traverses.clear();
@@ -1120,7 +1119,21 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
 		if (flags & img_SFLAG_ENTRANCE) {
 		    flags ^= (img_SFLAG_ENTRANCE | LFLAG_ENTRANCE);
 		}
-		LabelInfo* label = new LabelInfo(pt, wxString(survey->label, wxConvUTF8), flags);
+		wxString s(survey->label, wxConvUTF8);
+		if (s.empty()) {
+		    // If label isn't valid UTF-8 then this conversion will
+		    // give an empty string.  In this case, assume that the
+		    // label is CP1252 (the Microsoft superset of ISO8859-1).
+		    static wxCSConv ConvCP1252(wxFONTENCODING_CP1252);
+		    s = wxString(survey->label, ConvCP1252);
+		    if (s.empty()) {
+			// Or if that doesn't work (ConvCP1252 doesn't like
+			// strings with some bytes in) let's just go for
+			// ISO8859-1.
+			s = wxString(survey->label, wxConvISO8859_1);
+		    }
+		}
+		LabelInfo* label = new LabelInfo(pt, s, flags);
 		if (label->IsEntrance()) {
 		    m_NumEntrances++;
 		}
@@ -1274,20 +1287,6 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
     if (datemax < m_DateMin) m_DateMin = datemax;
     m_DateExt = datemax - m_DateMin;
 
-    // Sort the labels.
-    m_Labels.sort(LabelCmp(separator));
-
-    // Fill the tree of stations and prefixes.
-    FillTree();
-
-    // Sort labels so that entrances are displayed in preference,
-    // then fixed points, then exported points, then other points.
-    //
-    // Also sort by leaf name so that we'll tend to choose labels
-    // from different surveys, rather than labels from surveys which
-    // are earlier in the list.
-    m_Labels.sort(LabelPlotCmp(separator));
-
     // Centre the dataset around the origin.
     CentreDataset(Vector3(xmin, ymin, zmin));
 
@@ -1306,12 +1305,6 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
     // Update window title.
     SetTitle(m_Title + " - "APP_NAME);
 
-    if (!m_FindBox->GetValue().empty()) {
-	// Highlight any stations matching the current search.
-	wxCommandEvent dummy;
-	OnFind(dummy);
-    }
-
     return true;
 }
 
@@ -1446,7 +1439,9 @@ void MainFrm::FillTree()
 		// are the same.
 		// Note that we require a match of a whole number of parts
 		// between dots!
-		for (size_t i = 0; prefix[i] == current_prefix[i]; ++i) {
+		size_t n = min(prefix.length(), current_prefix.length());
+		size_t i;
+		for (i = 0; i < n && prefix[i] == current_prefix[i]; ++i) {
 		    if (prefix[i] == separator) count = i + 1;
 		}
 	    } else {
@@ -1644,6 +1639,26 @@ void MainFrm::InitialiseAfterLoad(const wxString & file)
     if (!same_file)
 	m_File = file;
 
+    // Sort the labels ready for filling the tree.
+    m_Labels.sort(LabelCmp(separator));
+
+    // Fill the tree of stations and prefixes.
+    FillTree();
+
+    // Sort labels so that entrances are displayed in preference,
+    // then fixed points, then exported points, then other points.
+    //
+    // Also sort by leaf name so that we'll tend to choose labels
+    // from different surveys, rather than labels from surveys which
+    // are earlier in the list.
+    m_Labels.sort(LabelPlotCmp(separator));
+
+    if (!m_FindBox->GetValue().empty()) {
+	// Highlight any stations matching the current search.
+	wxCommandEvent dummy;
+	OnFind(dummy);
+    }
+
     wxWindow * win = NULL;
     if (m_Splitter->GetWindow2() == NULL) {
 	win = m_Splitter->GetWindow1();
@@ -1688,17 +1703,16 @@ void MainFrm::OnOpen(wxCommandEvent&)
 		     "|%s|*.dat;*.mak"CASE("*.DAT;*.MAK")
 		     "|%s|*.xyz"CASE("*.XYZ")
 		     "|%s|%s"),
-		     wxT("All survey files"),
+		     wmsg(/*All survey files*/229).c_str(),
 		     wmsg(/*Survex 3d files*/207).c_str(),
-		     wxT("Survex svx files"),
+		     wmsg(/*Survex svx files*/329).c_str(),
 		     wmsg(/*Compass PLT files*/324).c_str(),
-		     wxT("Compass DAT and MAK files"),
+		     wmsg(/*Compass DAT and MAK files*/330).c_str(),
 		     wmsg(/*CMAP XYZ files*/325).c_str(),
 		     wmsg(/*All files*/208).c_str(),
 		     wxFileSelectorDefaultWildcardStr);
 #endif
-    // FIXME: drop "3d" from this message?
-    wxFileDialog dlg(this, wmsg(/*Select a 3d file to view*/206),
+    wxFileDialog dlg(this, wmsg(/*Select a survey file to view*/206),
 		     wxString(), wxString(),
 		     filetypes, wxFD_OPEN|wxFD_FILE_MUST_EXIST);
     if (dlg.ShowModal() == wxID_OK) {
@@ -1820,11 +1834,8 @@ void MainFrm::UpdateStatusBar()
 void MainFrm::ClearTreeSelection()
 {
     m_Tree->UnselectAll();
-    if (!dist_text.empty()) {
-	dist_text = wxString();
-	UpdateStatusBar();
-    }
     m_Gfx->SetThere();
+    ShowInfo(NULL);
 }
 
 void MainFrm::ClearCoords()
@@ -1886,7 +1897,7 @@ void MainFrm::SetCoords(Double x, Double y)
 
 	wxString brg_unit;
 	if (m_Gfx->GetDegrees()) {
-	    brg_unit = wmsg(/*&deg;*/344);
+	    brg_unit = wmsg(/*°*/344);
 	} else {
 	    brg *= 400.0 / 360.0;
 	    brg_unit = wmsg(/*grad*/345);
@@ -1990,7 +2001,7 @@ void MainFrm::ShowInfo(const LabelInfo *here)
 	}
 	wxString brg_unit;
 	if (m_Gfx->GetDegrees()) {
-	    brg_unit = wmsg(/*&deg;*/344);
+	    brg_unit = wmsg(/*°*/344);
 	} else {
 	    brg *= 400.0 / 360.0;
 	    brg_unit = wmsg(/*grad*/345);
@@ -2170,14 +2181,13 @@ void MainFrm::OnPresExportMovie(wxCommandEvent&)
     // default might make more sense?
     wxString baseleaf;
     wxFileName::SplitPath(m_File, NULL, NULL, &baseleaf, NULL, wxPATH_NATIVE);
-    wxFileDialog dlg(this, wxT("Export Movie"), wxString(),
+    wxFileDialog dlg(this, wmsg(/*Export Movie*/331), wxString(),
 		     baseleaf + wxT(".mpg"),
 		     wxT("MPEG|*.mpg|AVI|*.avi|QuickTime|*.mov|WMV|*.wmv;*.asf"),
 		     wxFD_SAVE|wxFD_OVERWRITE_PROMPT);
     if (dlg.ShowModal() == wxID_OK) {
-	if (!m_Gfx->ExportMovie(dlg.GetPath())) {
-	    wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file `%s'*/110), dlg.GetPath().c_str()));
-	}
+	// Error is reported by GfxCore.
+	(void)m_Gfx->ExportMovie(dlg.GetPath());
     }
 }
 
@@ -2369,9 +2379,9 @@ void MainFrm::OnFind(wxCommandEvent&)
     m_Gfx->ForceRefresh();
 
     if (!m_NumHighlighted) {
-        GetToolBar()->SetToolShortHelp(button_HIDE, wmsg(/*No matches were found.*/328));
+	GetToolBar()->SetToolShortHelp(button_HIDE, wmsg(/*No matches were found.*/328));
     } else {
-        GetToolBar()->SetToolShortHelp(button_HIDE, wxString::Format(wxT("Unhilight %d found stations"), m_NumHighlighted));
+	GetToolBar()->SetToolShortHelp(button_HIDE, wxString::Format(wmsg(/*Hide %d found stations*/334).c_str(), m_NumHighlighted));
     }
 }
 
@@ -2410,6 +2420,7 @@ void MainFrm::OnGotoFound(wxCommandEvent&)
 void MainFrm::OnHide(wxCommandEvent&)
 {
     m_FindBox->SetValue(wxString());
+    GetToolBar()->SetToolShortHelp(button_HIDE, wmsg(/*Hide*/333));
 }
 
 void MainFrm::OnHideUpdate(wxUpdateUIEvent& ui)
@@ -2454,36 +2465,4 @@ void MainFrm::ViewFullScreen() {
     static bool sidepanel;
     if (IsFullScreen()) sidepanel = ShowingSidePanel();
     if (sidepanel) ToggleSidePanel();
-#ifdef __WXGTK__
-    // wxGTK doesn't currently remove the toolbar, statusbar, or menubar.
-    // Can't work out how to lose the menubar right now, but this works for
-    // the other two.  FIXME: tidy this code up and submit a patch for
-    // wxWidgets.
-    wxToolBar *tb = GetToolBar();
-    if (tb) tb->Show(!IsFullScreen());
-    wxStatusBar *sb = GetStatusBar();
-    if (sb) sb->Show(!IsFullScreen());
-#if 0
-    // FIXME: This sort of works, but we lose the top-level shortcuts
-    // (e.g. alt-F for File)
-    wxMenuBar *mb = GetMenuBar();
-    if (mb) {
-	static list<wxMenu *> menus;
-	static list<wxString> labels;
-	if (IsFullScreen()) {
-	    // remove menus
-	    for (int c = mb->GetMenuCount(); c >= 0; --c) {
-		labels.push_back(mb->GetLabelTop(c));
-		menus.push_back(mb->Remove(c));
-	    }
-	} else {
-	    while (!menus.empty()) {
-		mb->Append(menus.back(), labels.back());
-		menus.pop_back();
-		labels.pop_back();
-	    }
-	}
-    }
-#endif
-#endif
 }
