@@ -4,7 +4,7 @@
 //  Main frame handling for Aven.
 //
 //  Copyright (C) 2000-2003,2005 Mark R. Shinwell
-//  Copyright (C) 2001-2003,2004,2005,2006,2010 Olly Betts
+//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -52,12 +52,9 @@ using namespace std;
 #define MARK_PREV 3
 
 enum {
-    menu_FILE_OPEN = 1000,
-    menu_FILE_PRINT,
-    menu_FILE_PAGE_SETUP,
+    menu_FILE_PAGE_SETUP = 1000,
     menu_FILE_SCREENSHOT,
     menu_FILE_EXPORT,
-    menu_FILE_QUIT,
     menu_PRES_NEW,
     menu_PRES_OPEN,
     menu_PRES_SAVE,
@@ -71,7 +68,6 @@ enum {
     menu_PRES_FF,
     menu_PRES_FFF,
     menu_PRES_PAUSE,
-    menu_PRES_STOP,
     menu_ROTATION_START,
     menu_ROTATION_STOP,
     menu_ROTATION_TOGGLE,
@@ -92,8 +88,6 @@ enum {
     menu_ORIENT_ELEVATION,
     menu_ORIENT_HIGHER_VP,
     menu_ORIENT_LOWER_VP,
-    menu_ORIENT_ZOOM_IN,
-    menu_ORIENT_ZOOM_OUT,
     menu_ORIENT_DEFAULTS,
     menu_VIEW_SHOW_LEGS,
     menu_VIEW_SHOW_CROSSES,
@@ -113,13 +107,12 @@ enum {
     menu_VIEW_FOG,
     menu_VIEW_SMOOTH_LINES,
     menu_VIEW_FULLSCREEN,
-    menu_VIEW_PREFERENCES,
     menu_VIEW_COLOUR_BY_DEPTH,
     menu_VIEW_COLOUR_BY_DATE,
     menu_VIEW_COLOUR_BY_ERROR,
     menu_IND_COMPASS,
     menu_IND_CLINO,
-    menu_IND_DEPTH_BAR,
+    menu_IND_COLOUR_KEY,
     menu_IND_SCALE_BAR,
     menu_CTL_INDICATORS,
     menu_CTL_SIDE_PANEL,
@@ -127,9 +120,7 @@ enum {
     menu_CTL_DEGREES,
     menu_CTL_REVERSE,
     menu_CTL_CANCEL_DIST_LINE,
-    menu_HELP_ABOUT,
     textctrl_FIND,
-    button_FIND,
     button_HIDE,
     listctrl_PRES
 };
@@ -252,10 +243,6 @@ class MainFrm : public wxFrame {
 //    void FixLRUD(traverse & centreline);
     void CentreDataset(const Vector3 & vmin);
 
-    wxString GetTabMsg(int key) {
-	wxString x(wmsg(key)); x.Replace(wxT("##"), wxT("\t")); x.Replace(wxT("@"), wxT("&")); return x;
-    }
-
     void CreateMenuBar();
     void CreateToolBar();
     void CreateSidePanel();
@@ -266,7 +253,6 @@ class MainFrm : public wxFrame {
 
 public:
     MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size);
-    ~MainFrm();
 
     void InitialiseAfterLoad(const wxString & file);
 
@@ -367,7 +353,7 @@ public:
     void OnZoomInUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnZoomInUpdate(event); }
     void OnZoomOutUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnZoomOutUpdate(event); }
     void OnToggleScalebarUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnToggleScalebarUpdate(event); }
-    void OnToggleDepthbarUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnToggleDepthbarUpdate(event); }
+    void OnToggleColourKeyUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnToggleColourKeyUpdate(event); }
     void OnViewCompassUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnViewCompassUpdate(event); }
     void OnViewGridUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnViewGridUpdate(event); }
     void OnViewBoundingBoxUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnViewBoundingBoxUpdate(event); }
@@ -415,7 +401,7 @@ public:
     void OnZoomIn(wxCommandEvent&) { if (m_Control) m_Control->OnZoomIn(); }
     void OnZoomOut(wxCommandEvent&) { if (m_Control) m_Control->OnZoomOut(); }
     void OnToggleScalebar(wxCommandEvent&) { if (m_Control) m_Control->OnToggleScalebar(); }
-    void OnToggleDepthbar(wxCommandEvent&) { if (m_Control) m_Control->OnToggleDepthbar(); }
+    void OnToggleColourKey(wxCommandEvent&) { if (m_Control) m_Control->OnToggleColourKey(); }
     void OnViewCompass(wxCommandEvent&) { if (m_Control) m_Control->OnViewCompass(); }
     void OnViewClino(wxCommandEvent&) { if (m_Control) m_Control->OnViewClino(); }
     void OnViewGrid(wxCommandEvent&) { if (m_Control) m_Control->OnViewGrid(); }
@@ -537,10 +523,14 @@ private:
     DECLARE_EVENT_TABLE()
 };
 
-// wxGTK loses the dialog under the always-on-top, maximised window.
-// By creating this object on the stack, you can get the dialog on top...
+// Older wxGTK loses pop-up dialogs under the always-on-top, maximised window.
+// Not sure when this got fixed, but wx 2.8.10 definitely works properly on
+// Debian squeeze.
+//
+// To work around this issue, create this object on the stack, and it will
+// temporarily un-fullscreen the window while the dialog as a workaround.
 class AvenAllowOnTop {
-#ifndef _WIN32
+#if defined __WXGTK__ && !wxCHECK_VERSION(2,8,10)
 	MainFrm * mainfrm;
     public:
 	AvenAllowOnTop(MainFrm * mainfrm_) {
