@@ -1,6 +1,6 @@
 /* printwx.cc */
 /* wxWidgets specific parts of Survex wxWidgets printing code */
-/* Copyright (C) 1993-2003,2004,2005,2006,2010 Olly Betts
+/* Copyright (C) 1993-2003,2004,2005,2006,2010,2011 Olly Betts
  * Copyright (C) 2001,2004 Philip Underwood
  *
  * This program is free software; you can redistribute it and/or modify
@@ -54,11 +54,7 @@ using namespace std;
 #include "printwx.h"
 
 enum {
-	svx_PRINT = 1200,
-	svx_EXPORT,
-#ifdef AVEN_PRINT_PREVIEW
-	svx_PREVIEW,
-#endif
+	svx_EXPORT = 1200,
 	svx_SCALE,
 	svx_BEARING,
 	svx_TILT,
@@ -76,9 +72,9 @@ enum {
 class svxPrintout : public wxPrintout {
     MainFrm *mainfrm;
     layout *m_layout;
-    wxString m_title;
     wxPageSetupDialogData* m_data;
     wxDC* pdc;
+    // Currently unused, but "skip blank pages" would use it.
     static const int cur_pass = 0;
 
     wxPen *pen_frame, *pen_cross, *pen_surface_leg, *pen_leg;
@@ -109,10 +105,8 @@ class svxPrintout : public wxPrintout {
     void WriteString(const wxString & s);
     void DrawEllipse(long x, long y, long r, long R);
     void SolidRectangle(long x, long y, long w, long h);
-    int Charset(void);
     int Pre();
     void NewPage(int pg, int pagesX, int pagesY);
-    void ShowPage(const char *szPageDetails);
     void PlotLR(const vector<XSect> & centreline);
     void PlotUD(const vector<XSect> & centreline);
     char * Init(FILE **fh_list, bool fCalibrate);
@@ -121,7 +115,6 @@ class svxPrintout : public wxPrintout {
     bool OnPrintPage(int pageNum);
     void GetPageInfo(int *minPage, int *maxPage,
 		     int *pageFrom, int *pageTo);
-    wxString GetTitle();
     bool HasPage(int pageNum);
     void OnBeginPrinting();
     void OnEndPrinting();
@@ -132,13 +125,15 @@ BEGIN_EVENT_TABLE(svxPrintDlg, wxDialog)
     EVT_COMBOBOX(svx_SCALE, svxPrintDlg::OnChange)
     EVT_SPINCTRL(svx_BEARING, svxPrintDlg::OnChangeSpin)
     EVT_SPINCTRL(svx_TILT, svxPrintDlg::OnChangeSpin)
-    EVT_BUTTON(svx_PRINT, svxPrintDlg::OnPrint)
+    EVT_BUTTON(wxID_PRINT, svxPrintDlg::OnPrint)
     EVT_BUTTON(svx_EXPORT, svxPrintDlg::OnExport)
 #ifdef AVEN_PRINT_PREVIEW
-    EVT_BUTTON(svx_PREVIEW, svxPrintDlg::OnPreview)
+    EVT_BUTTON(wxID_PREVIEW, svxPrintDlg::OnPreview)
 #endif
     EVT_BUTTON(svx_PLAN, svxPrintDlg::OnPlan)
     EVT_BUTTON(svx_ELEV, svxPrintDlg::OnElevation)
+    EVT_UPDATE_UI(svx_PLAN, svxPrintDlg::OnPlanUpdate)
+    EVT_UPDATE_UI(svx_ELEV, svxPrintDlg::OnElevationUpdate)
     EVT_CHECKBOX(svx_LEGS, svxPrintDlg::OnChange)
     EVT_CHECKBOX(svx_STATIONS, svxPrintDlg::OnChange)
     EVT_CHECKBOX(svx_NAMES, svxPrintDlg::OnChange)
@@ -174,7 +169,6 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 {
     m_scale = NULL;
     m_printSize = NULL;
-    m_tilttext = NULL;
     m_bearing = NULL;
     m_tilt = NULL;
     m_legs = NULL;
@@ -188,18 +182,16 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
     m_layout.Shots = legs;
     m_layout.Surface = surf;
     m_layout.datestamp = datestamp;
-    m_layout.rot = int(angle + .001);
+    m_layout.rot = int(angle);
     m_layout.title = title;
     if (mainfrm->IsExtendedElevation()) {
 	m_layout.view = layout::EXTELEV;
 	if (m_layout.rot != 0 && m_layout.rot != 180) m_layout.rot = 0;
 	m_layout.tilt = 0;
     } else {
-	// FIXME rot and tilt shouldn't be integers, but for now add a small
-	// fraction before forcing to int as otherwise plan view ends up being
-	// 89 degrees!
-	m_layout.tilt = int(tilt_angle + .001);
-	if (m_layout.tilt == 90) {
+	// FIXME rot and tilt shouldn't be integers.
+	m_layout.tilt = int(tilt_angle);
+	if (m_layout.tilt == -90) {
 	    m_layout.view = layout::PLAN;
 	} else if (m_layout.tilt == 0) {
 	    m_layout.view = layout::ELEV;
@@ -211,7 +203,7 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
     /* setup our print dialog*/
     wxBoxSizer* v1 = new wxBoxSizer(wxVERTICAL);
     wxBoxSizer* h1 = new wxBoxSizer(wxHORIZONTAL); // holds controls
-    wxBoxSizer* v2 = new wxStaticBoxSizer(new wxStaticBox(this, -1, wmsg(/*View*/255)), wxVERTICAL);
+    wxBoxSizer* v2 = new wxStaticBoxSizer(new wxStaticBox(this, -1, wmsg(/*View*/283)), wxVERTICAL);
     wxBoxSizer* v3 = new wxStaticBoxSizer(new wxStaticBox(this, -1, wmsg(/*Elements*/256)), wxVERTICAL);
     wxBoxSizer* h2 = new wxBoxSizer(wxHORIZONTAL); // holds buttons
 
@@ -252,9 +244,9 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 	v2->Add(anglebox, 0, wxALIGN_LEFT|wxALL, 0);
 
 	wxBoxSizer * planelevsizer = new wxBoxSizer(wxHORIZONTAL);
-	planelevsizer->Add(new wxButton(this, svx_PLAN, wmsg(/*Plan*/117)),
+	planelevsizer->Add(new wxButton(this, svx_PLAN, wmsg(/*P&lan view*/117)),
 			   0, wxALIGN_CENTRE_VERTICAL|wxALL, 5);
-	planelevsizer->Add(new wxButton(this, svx_ELEV, wmsg(/*Elevation*/118)),
+	planelevsizer->Add(new wxButton(this, svx_ELEV, wmsg(/*&Elevation*/285)),
 			   0, wxALIGN_CENTRE_VERTICAL|wxALL, 5);
 
 	v2->Add(planelevsizer, 0, wxALIGN_LEFT|wxALL, 5);
@@ -284,15 +276,15 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
     v1->Add(h1, 0, wxALIGN_LEFT|wxALL, 5);
 
     wxButton * but;
-    but = new wxButton(this, wxID_CANCEL, wmsg(/*&Cancel*/402));
+    but = new wxButton(this, wxID_CANCEL);
     h2->Add(but, 0, wxALIGN_RIGHT|wxALL, 5);
     if (printing) {
 #ifdef AVEN_PRINT_PREVIEW
-	but = new wxButton(this, svx_PREVIEW, wmsg(/*Pre&view*/401));
+	but = new wxButton(this, wxID_PREVIEW);
 	h2->Add(but, 0, wxALIGN_RIGHT|wxALL, 5);
-	but = new wxButton(this, svx_PRINT, wmsg(/*&Print*/400));
+	but = new wxButton(this, wxID_PRINT);
 #else
-	but = new wxButton(this, svx_PRINT, wmsg(/*&Print*/400) + wxT("..."));
+	but = new wxButton(this, wxID_PRINT, wmsg(/*&Print...*/400));
 #endif
     } else {
 	but = new wxButton(this, svx_EXPORT, wmsg(/*&Export...*/230));
@@ -328,15 +320,17 @@ svxPrintDlg::OnExport(wxCommandEvent&) {
     UIToLayout();
     wxString baseleaf;
     wxFileName::SplitPath(m_File, NULL, NULL, &baseleaf, NULL, wxPATH_NATIVE);
-    wxFileDialog dlg(this, wxT("Export as:"), wxString(), baseleaf,
-		     wxT("DXF files|*.dxf|SVG files|*.svg|Sketch files|*.sk|EPS files|*.eps|Compass PLT for use with Carto|*.plt|HPGL for plotters|*.hpgl"),
+    wxFileDialog dlg(this, wmsg(/*Export as:*/401), wxString(), baseleaf,
+		     wmsg(/*DXF files|*.dxf|SVG files|*.svg|Sketch files|*.sk|EPS files|*.eps|Compass PLT for use with Carto|*.plt|HPGL for plotters|*.hpgl*/96),
 		     wxFD_SAVE|wxFD_OVERWRITE_PROMPT);
     if (dlg.ShowModal() == wxID_OK) {
 	if (!Export(dlg.GetPath(), m_layout.title, mainfrm,
 		    m_layout.rot, m_layout.tilt,
 		    m_layout.Labels, m_layout.Crosses,
 		    m_layout.Shots, m_layout.Surface)) {
-	    wxGetApp().ReportError(wxString::Format(wxT("Couldn't write file `%s'"), m_File.c_str()));
+	    wxString m = wxString::Format(wmsg(/*Couldn't write file `%s'*/402).c_str(),
+					  m_File.c_str());
+	    wxGetApp().ReportError(m);
 	}
     }
     Destroy();
@@ -390,7 +384,7 @@ svxPrintDlg::OnPreview(wxCommandEvent&) {
 
 void
 svxPrintDlg::OnPlan(wxCommandEvent&) {
-    m_tilt->SetValue(90);
+    m_tilt->SetValue(-90);
     SomethingChanged();
 }
 
@@ -400,6 +394,16 @@ svxPrintDlg::OnElevation(wxCommandEvent&) {
     SomethingChanged();
 }
 
+void
+svxPrintDlg::OnPlanUpdate(wxUpdateUIEvent& e) {
+    e.Enable(m_tilt->GetValue() != -90);
+}
+
+void
+svxPrintDlg::OnElevationUpdate(wxUpdateUIEvent& e) {
+    e.Enable(m_tilt->GetValue() != 0);
+}
+
 void
 svxPrintDlg::OnChangeSpin(wxSpinEvent&e) {
     SomethingChanged();
@@ -416,6 +420,14 @@ svxPrintDlg::SomethingChanged() {
     if (!m_printSize) return;
     // Update the bounding box.
     RecalcBounds();
+
+    if (m_scale) {
+	(m_scale->GetValue()).ToDouble(&(m_layout.Scale));
+	if (m_layout.Scale == 0.0) {
+	    m_layout.pick_scale(1, 1);
+	}
+    }
+
     if (m_layout.xMax >= m_layout.xMin) {
 	m_layout.pages_required();
 	m_printSize->SetLabel(wxString::Format(wmsg(/*%d pages (%dx%d)*/257), m_layout.pages, m_layout.pagesX, m_layout.pagesY));
@@ -433,13 +445,6 @@ svxPrintDlg::LayoutToUI(){
     m_surface->SetValue(m_layout.Surface);
     if (m_layout.view != layout::EXTELEV) {
 	m_tilt->SetValue(m_layout.tilt);
-	// FIXME: enable both buttons
-	if (m_layout.tilt > 89) {
-	    // FIXME: disable Plan button
-	} else if (m_layout.tilt == 0) {
-	    // FIXME: disable Elevation button
-	}
-
 	m_bearing->SetValue(m_layout.rot);
     }
 
@@ -468,7 +473,7 @@ svxPrintDlg::UIToLayout(){
 
     if (m_layout.view != layout::EXTELEV) {
 	m_layout.tilt = m_tilt->GetValue();
-	if (m_layout.tilt == 90) {
+	if (m_layout.tilt == -90) {
 	    m_layout.view = layout::PLAN;
 	} else if (m_layout.tilt == 0) {
 	    m_layout.view = layout::ELEV;
@@ -477,13 +482,6 @@ svxPrintDlg::UIToLayout(){
 	}
 	m_layout.rot = m_bearing->GetValue();
     }
-
-    if (m_scale) {
-	(m_scale->GetValue()).ToDouble(&(m_layout.Scale));
-	if (m_layout.Scale == 0.0) {
-	    m_layout.pick_scale(1, 1);
-	}
-    }
 }
 
 void
@@ -510,7 +508,7 @@ svxPrintDlg::RecalcBounds()
 		double X = x * COS - y * SIN;
 		if (X > m_layout.xMax) m_layout.xMax = X;
 		if (X < m_layout.xMin) m_layout.xMin = X;
-		double Y = (x * SIN + y * COS) * SINT + z * COST;
+		double Y = z * COST - (x * SIN + y * COS) * SINT;
 		if (Y > m_layout.yMax) m_layout.yMax = Y;
 		if (Y < m_layout.yMin) m_layout.yMin = Y;
 	    }
@@ -529,7 +527,7 @@ svxPrintDlg::RecalcBounds()
 		double X = x * COS - y * SIN;
 		if (X > m_layout.xMax) m_layout.xMax = X;
 		if (X < m_layout.xMin) m_layout.xMin = X;
-		double Y = (x * SIN + y * COS) * SINT + z * COST;
+		double Y = z * COST - (x * SIN + y * COS) * SINT;
 		if (Y > m_layout.yMax) m_layout.yMax = Y;
 		if (Y < m_layout.yMin) m_layout.yMin = Y;
 	    }
@@ -545,7 +543,7 @@ svxPrintDlg::RecalcBounds()
 		double X = x * COS - y * SIN;
 		if (X > m_layout.xMax) m_layout.xMax = X;
 		if (X < m_layout.xMin) m_layout.xMin = X;
-		double Y = (x * SIN + y * COS) * SINT + z * COST;
+		double Y = z * COST - (x * SIN + y * COS) * SINT;
 		if (Y > m_layout.yMax) m_layout.yMax = Y;
 		if (Y < m_layout.yMin) m_layout.yMin = Y;
 	    }
@@ -554,8 +552,6 @@ svxPrintDlg::RecalcBounds()
     }
 }
 
-#define DEG "\xB0" /* degree symbol in iso-8859-1 */
-
 static int xpPageWidth, ypPageDepth;
 static long MarginLeft, MarginRight, MarginTop, MarginBottom;
 static long x_offset, y_offset;
@@ -573,7 +569,6 @@ svxPrintout::svxPrintout(MainFrm *mainfrm_, layout *l,
 {
     mainfrm = mainfrm_;
     m_layout = l;
-    m_title = title;
     m_data = data;
 }
 
@@ -581,17 +576,17 @@ void
 svxPrintout::draw_info_box()
 {
    layout *l = m_layout;
-   int boxwidth = 60;
+   int boxwidth = 70;
    int boxheight = 30;
 
    SetColour(PR_COLOUR_FRAME);
 
+   int div = boxwidth;
    if (l->view != layout::EXTELEV) {
-      boxwidth = 100;
-      boxheight = 40;
-      MOVEMM(60,40);
-      DRAWMM(60, 0);
-      MOVEMM(0, 30); DRAWMM(60, 30);
+      boxwidth += boxheight;
+      MOVEMM(div, boxheight);
+      DRAWMM(div, 0);
+      MOVEMM(0, 30); DRAWMM(div, 30);
    }
 
    MOVEMM(0, boxheight);
@@ -602,25 +597,27 @@ svxPrintout::draw_info_box()
       DRAWMM(0, boxheight);
    }
 
-   MOVEMM(0, 20); DRAWMM(60, 20);
-   MOVEMM(0, 10); DRAWMM(60, 10);
+   MOVEMM(0, 20); DRAWMM(div, 20);
+   MOVEMM(0, 10); DRAWMM(div, 10);
 
    switch (l->view) {
     case layout::PLAN: {
       long ax, ay, bx, by, cx, cy, dx, dy;
 
-#define RADIUS 16.0
-      DrawEllipse((long)(80.0 * l->scX), (long)(20.0 * l->scY),
-		  (long)(RADIUS * l->scX), (long)(RADIUS * l->scY));
+      long xc = boxwidth - boxheight / 2;
+      long yc = boxheight / 2;
+      const double RADIUS = boxheight * 0.4;
+      DrawEllipse(long(xc * l->scX), long(yc * l->scY),
+		  long(RADIUS * l->scX), long(RADIUS * l->scY));
 
-      ax = (long)((80 - 15 * sin(rad(000.0 + l->rot))) * l->scX);
-      ay = (long)((20 + 15 * cos(rad(000.0 + l->rot))) * l->scY);
-      bx = (long)((80 -  7 * sin(rad(180.0 + l->rot))) * l->scX);
-      by = (long)((20 +  7 * cos(rad(180.0 + l->rot))) * l->scY);
-      cx = (long)((80 - 15 * sin(rad(160.0 + l->rot))) * l->scX);
-      cy = (long)((20 + 15 * cos(rad(160.0 + l->rot))) * l->scY);
-      dx = (long)((80 - 15 * sin(rad(200.0 + l->rot))) * l->scX);
-      dy = (long)((20 + 15 * cos(rad(200.0 + l->rot))) * l->scY);
+      ax = (long)((xc - (RADIUS - 1) * sin(rad(000.0 + l->rot))) * l->scX);
+      ay = (long)((yc + (RADIUS - 1) * cos(rad(000.0 + l->rot))) * l->scY);
+      bx = (long)((xc - RADIUS * 0.5 * sin(rad(180.0 + l->rot))) * l->scX);
+      by = (long)((yc + RADIUS * 0.5 * cos(rad(180.0 + l->rot))) * l->scY);
+      cx = (long)((xc - (RADIUS - 1) * sin(rad(160.0 + l->rot))) * l->scX);
+      cy = (long)((yc + (RADIUS - 1) * cos(rad(160.0 + l->rot))) * l->scY);
+      dx = (long)((xc - (RADIUS - 1) * sin(rad(200.0 + l->rot))) * l->scX);
+      dy = (long)((yc + (RADIUS - 1) * cos(rad(200.0 + l->rot))) * l->scY);
 
       MoveTo(ax, ay);
       DrawTo(bx, by);
@@ -630,55 +627,71 @@ svxPrintout::draw_info_box()
       DrawTo(bx, by);
 
       SetColour(PR_COLOUR_TEXT);
-      MOVEMM(62, 36);
+      MOVEMM(div, boxheight - 5);
       WriteString(wmsg(/*North*/115));
 
-      MOVEMM(5, 23);
-      WriteString(wmsg(/*Plan view*/117));
+      wxString angle;
+      angle.Printf(wxT("%03d"), l->rot);
+      angle += wmsg(/*°*/344);
+      wxString s;
+      s.Printf(wmsg(/*Plan view, %s up page*/168), angle.c_str());
+      MOVEMM(2, 12); WriteString(s);
       break;
     }
-    case layout::ELEV: case layout::TILT:
-      MOVEMM(65, 15); DRAWMM(70, 12); DRAWMM(68, 15); DRAWMM(70, 18);
+    case layout::ELEV: case layout::TILT: {
+      const int L = div + 2;
+      const int R = boxwidth - 2;
+      const int H = boxheight / 2 - 5;
+      MOVEMM(L, H); DRAWMM(L + 5, H - 3); DRAWMM(L + 3, H); DRAWMM(L + 5, H + 3);
 
-      DRAWMM(65, 15); DRAWMM(95, 15);
+      DRAWMM(L, H); DRAWMM(R, H);
 
-      DRAWMM(90, 18); DRAWMM(92, 15); DRAWMM(90, 12); DRAWMM(95, 15);
+      DRAWMM(R - 5, H + 3); DRAWMM(R - 3, H); DRAWMM(R - 5, H - 3); DRAWMM(R, H);
 
-      MOVEMM(80, 13); DRAWMM(80, 17);
+      MOVEMM((L + R) / 2, H - 2); DRAWMM((L + R) / 2, H + 2);
 
       SetColour(PR_COLOUR_TEXT);
-      MOVEMM(62, 33);
+      MOVEMM(div, boxheight - 5);
       WriteString(wmsg(/*Elevation on*/116));
       
-      MOVEMM(65, 20); 
-      WriteString(wxString::Format(wxT("%03d"DEG),
-				   (l->rot + 270) % 360 ));
-      MOVEMM(85, 20);
-      WriteString(wxString::Format(wxT("%03d"DEG),
-				   (l->rot + 90) % 360 ));
-      MOVEMM(5, 23);
-      WriteString(wmsg(/*Elevation*/118));
+      MOVEMM(L, boxheight / 2);
+      WriteString(wxString::Format(wxT("%03d%s"),
+				   (l->rot + 270) % 360,
+				   wmsg(/*°*/344).c_str()));
+      MOVEMM(R - 10, boxheight / 2);
+      WriteString(wxString::Format(wxT("%03d%s"),
+				   (l->rot + 90) % 360,
+				   wmsg(/*°*/344).c_str()));
+
+      wxString angle;
+      angle.Printf(wxT("%03d"), l->rot);
+      angle += wmsg(/*°*/344);
+      wxString s;
+      if (l->view == layout::ELEV) {
+	  s.Printf(wmsg(/*Elevation facing %s*/169), angle.c_str());
+      } else {
+	  wxString a2;
+	  a2.Printf(wxT("%d"), l->tilt);
+	  a2 += wmsg(/*°*/344);
+	  s.Printf(wmsg(/*Elevation facing %s, tilted %s*/284), angle.c_str(), a2.c_str());
+      }
+      MOVEMM(2, 12); WriteString(s);
       break;
+    }
     case layout::EXTELEV:
       SetColour(PR_COLOUR_TEXT);
-      MOVEMM(5, 13);
+      MOVEMM(2, 12);
       WriteString(wmsg(/*Extended elevation*/191));
       break;
    }
 
-   MOVEMM(5, boxheight - 7); WriteString(l->title);
+   MOVEMM(2, boxheight - 8); WriteString(l->title);
 
-   MOVEMM(5, boxheight - 27); 
+   MOVEMM(2, 2);
+   // FIXME: "Original Scale" better?
    WriteString(wxString::Format(wmsg(/*Scale*/154) + wxT(" 1:%.0f"),
 				l->Scale));
 
-   if (l->view != layout::EXTELEV) {
-      wxString s;
-      s = wmsg(l->view == layout::PLAN ? /*Up page*/168 : /*View*/169);
-      s.Append(wxString::Format(wxT(" %03d"DEG), l->rot));
-      MOVEMM(5, 3); WriteString(s);
-   }
-
    /* This used to be a copyright line, but it was occasionally
     * mis-interpreted as us claiming copyright on the survey, so let's
     * give the website URL instead */
@@ -1025,7 +1038,7 @@ svxPrintout::OnPrintPage(int pageNum) {
 		double y = pos->GetY();
 		double z = pos->GetZ();
 		double X = x * COS - y * SIN;
-		double Y = (x * SIN + y * COS) * SINT + z * COST;
+		double Y = z * COST - (x * SIN + y * COS) * SINT;
 		long px = (long)((X * Sc + l->xOrg) * l->scX);
 		long py = (long)((Y * Sc + l->yOrg) * l->scY);
 		if (pos == trav->begin()) {
@@ -1079,7 +1092,7 @@ svxPrintout::OnPrintPage(int pageNum) {
 	    double pz = (*label)->GetZ();
 	    if (l->Surface || (*label)->IsUnderground()) {
 		double X = px * COS - py * SIN;
-		double Y = (px * SIN + py * COS) * SINT + pz * COST;
+		double Y = pz * COST - (px * SIN + py * COS) * SINT;
 		long xnew, ynew;
 		xnew = (long)((X * Sc + l->xOrg) * l->scX);
 		ynew = (long)((Y * Sc + l->yOrg) * l->scY);
@@ -1097,16 +1110,6 @@ svxPrintout::OnPrintPage(int pageNum) {
 	}
     }
 
-    if (!l->Raw) {
-	char szTmp[256];
-	SetColour(PR_COLOUR_TEXT);
-	sprintf(szTmp,(const char*) l->footer.mb_str(), (const char*)l->title.mb_str(), pageNum, l->pagesX * l->pagesY,
-		(const char*)l->datestamp.mb_str());
-	ShowPage(szTmp);
-    } else {
-	ShowPage("");
-    }
-
     return true;
 }
 
@@ -1118,11 +1121,6 @@ svxPrintout::GetPageInfo(int *minPage, int *maxPage,
     *maxPage = *pageTo = m_layout->pages;
 }
 
-wxString
-svxPrintout::GetTitle() {
-    return m_title;
-}
-
 bool
 svxPrintout::HasPage(int pageNum) {
     return (pageNum <= m_layout->pages);
@@ -1174,12 +1172,12 @@ svxPrintout::OnBeginPrinting() {
 
 void
 svxPrintout::OnEndPrinting() {
-    delete(font_labels);
-    delete(font_default);
-    delete(pen_frame);
-    delete(pen_leg);
-    delete(pen_surface_leg);
-    delete(pen_cross);
+    delete font_labels;
+    delete font_default;
+    delete pen_frame;
+    delete pen_leg;
+    delete pen_surface_leg;
+    delete pen_cross;
 }
 
 
@@ -1384,12 +1382,6 @@ svxPrintout::SolidRectangle(long x, long y, long w, long h)
     pdc->DrawRectangle(X, Y - h, w, h);
 }
 
-int
-svxPrintout::Charset(void)
-{
-   return CHARSET_ISO_8859_1;
-}
-
 int
 svxPrintout::Pre()
 {
@@ -1421,25 +1413,19 @@ svxPrintout::NewPage(int pg, int pagesX, int pagesY)
 
     //we have to write the footer here. PostScript is being weird. Really weird.
     pdc->SetFont(*font_labels);
-    MoveTo((long)(6 * m_layout->scX) + clip.x_min,
-	   clip.y_min - (long)(7 * m_layout->scY));
-    wxString szFooter;
-    szFooter.Printf(m_layout->footer, 
-		    m_layout->title.c_str(), 
-		    pg,
-		    m_layout->pagesX * m_layout->pagesY,
-		    m_layout->datestamp.c_str());
-    WriteString(szFooter);
+    MoveTo(clip.x_min, clip.y_min - (long)(7 * m_layout->scY));
+    wxString footer;
+    footer.Printf(m_layout->footer,
+		  m_layout->title.c_str(),
+		  pg,
+		  m_layout->pagesX * m_layout->pagesY,
+		  m_layout->datestamp.c_str());
+    WriteString(footer);
     pdc->DestroyClippingRegion();
     pdc->SetClippingRegion(x_offset, y_offset,xpPageWidth+1, ypPageDepth+1);
     drawticks(clip, (int)(9 * m_layout->scX / POINTS_PER_MM), x, y);
 }
 
-void
-svxPrintout::ShowPage(const char *szPageDetails)
-{
-}
-
 void
 svxPrintout::PlotLR(const vector<XSect> & centreline)
 {
