@@ -1,7 +1,7 @@
 /* printwx.h */
 /* Device dependent part of Survex wxWidgets driver */
 /* Copyright (C) 2004 Philip Underwood
- * Copyright (C) 2004,2005,2006 Olly Betts
+ * Copyright (C) 2004,2005,2006,2011 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include "avenprcore.h"
 
 // The Gnome print dialog provides its own preview.  I assume Mac OS X does
-// to (MarkS made that change).
+// too (MarkS made that change).
 #if !defined __WXMAC__ && !defined wxUSE_LIBGNOMEPRINT
 # define AVEN_PRINT_PREVIEW
 #endif
@@ -38,11 +38,9 @@ class wxSpinEvent;
 
 // This dialog is also use for Export as well as Print.
 class svxPrintDlg : public wxDialog {
-protected:
 	layout m_layout;
 	wxComboBox* m_scale;
 	wxStaticText* m_printSize;
-	wxStaticText* m_tilttext;
 	wxSpinCtrl* m_bearing;
 	wxSpinCtrl* m_tilt;
 	wxCheckBox* m_legs;
@@ -58,6 +56,7 @@ protected:
 	void LayoutToUI();
 	void UIToLayout();
 	void RecalcBounds();
+	void SomethingChanged();
  public:
 	svxPrintDlg(MainFrm* parent, const wxString & filename,
 		    const wxString & title, const wxString & datestamp,
@@ -71,9 +70,10 @@ protected:
 #endif
 	void OnPlan(wxCommandEvent&);
 	void OnElevation(wxCommandEvent&);
+	void OnPlanUpdate(wxUpdateUIEvent& e);
+	void OnElevationUpdate(wxUpdateUIEvent& e);
 	void OnChangeSpin(wxSpinEvent& event);
 	void OnChange(wxCommandEvent& event);
-	void SomethingChanged();
  private:
 	DECLARE_EVENT_TABLE()
 };
