@@ -692,7 +692,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 	      char *buf;
 
-	      if (__asprintf (&buf, msg(/*%s: option `%s' is ambiguous&#10;*/300),
+	      if (__asprintf (&buf, msg(/*%s: option `%s' is ambiguous\n*/300),
 			      argv[0], argv[optind]) >= 0)
 		{
 
@@ -704,7 +704,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		  free (buf);
 		}
 #else
-	      fprintf (stderr, msg(/*%s: option `%s' is ambiguous&#10;*/300),
+	      fprintf (stderr, msg(/*%s: option `%s' is ambiguous\n*/300),
 		       argv[0], argv[optind]);
 #endif
 	    }
@@ -737,10 +737,10 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			{
 			  /* --option */
 #if defined _LIBC && defined USE_IN_LIBIO
-			  n = __asprintf (&buf, msg(/*%s: option `--%s' doesn't allow an argument&#10;*/303),
+			  n = __asprintf (&buf, msg(/*%s: option `--%s' doesn't allow an argument\n*/303),
 					  argv[0], pfound->name);
 #else
-			  fprintf (stderr, msg(/*%s: option `--%s' doesn't allow an argument&#10;*/303),
+			  fprintf (stderr, msg(/*%s: option `--%s' doesn't allow an argument\n*/303),
 				   argv[0], pfound->name);
 #endif
 			}
@@ -748,11 +748,11 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			{
 			  /* +option or -option */
 #if defined _LIBC && defined USE_IN_LIBIO
-			  n = __asprintf (&buf, msg(/*%s: option `%c%s' doesn't allow an argument&#10;*/302),
+			  n = __asprintf (&buf, msg(/*%s: option `%c%s' doesn't allow an argument\n*/302),
 					  argv[0], argv[optind - 1][0],
 					  pfound->name);
 #else
-			  fprintf (stderr, msg(/*%s: option `%c%s' doesn't allow an argument&#10;*/302),
+			  fprintf (stderr, msg(/*%s: option `%c%s' doesn't allow an argument\n*/302),
 				   argv[0], argv[optind - 1][0], pfound->name);
 #endif
 			}
@@ -787,7 +787,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		      char *buf;
 
-		      if (__asprintf (&buf, msg(/*%s: option `%s' requires an argument&#10;*/305),
+		      if (__asprintf (&buf, msg(/*%s: option `%s' requires an argument\n*/305),
 				      argv[0], argv[optind - 1]) >= 0)
 			{
 			  if (_IO_fwide (stderr, 0) > 0)
@@ -799,7 +799,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			}
 #else
 		      fprintf (stderr,
-			       msg(/*%s: option `%s' requires an argument&#10;*/305),
+			       msg(/*%s: option `%s' requires an argument\n*/305),
 			       argv[0], argv[optind - 1]);
 #endif
 		    }
@@ -837,10 +837,10 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		{
 		  /* --option */
 #if defined _LIBC && defined USE_IN_LIBIO
-		  n = __asprintf (&buf, msg(/*%s: unrecognized option `--%s'&#10;*/307),
+		  n = __asprintf (&buf, msg(/*%s: unrecognized option `--%s'\n*/307),
 				  argv[0], nextchar);
 #else
-		  fprintf (stderr, msg(/*%s: unrecognized option `--%s'&#10;*/307),
+		  fprintf (stderr, msg(/*%s: unrecognized option `--%s'\n*/307),
 			   argv[0], nextchar);
 #endif
 		}
@@ -848,10 +848,10 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		{
 		  /* +option or -option */
 #if defined _LIBC && defined USE_IN_LIBIO
-		  n = __asprintf (&buf, msg(/*%s: unrecognized option `%c%s'&#10;*/308),
+		  n = __asprintf (&buf, msg(/*%s: unrecognized option `%c%s'\n*/308),
 				  argv[0], argv[optind][0], nextchar);
 #else
-		  fprintf (stderr, msg(/*%s: unrecognized option `%c%s'&#10;*/308),
+		  fprintf (stderr, msg(/*%s: unrecognized option `%c%s'\n*/308),
 			   argv[0], argv[optind][0], nextchar);
 #endif
 		}
@@ -898,19 +898,19 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	      {
 		/* 1003.2 specifies the format of this message.  */
 #if defined _LIBC && defined USE_IN_LIBIO
-		n = __asprintf (&buf, msg(/*%s: illegal option -- %c&#10;*/309),
+		n = __asprintf (&buf, msg(/*%s: illegal option -- %c\n*/309),
 				argv[0], c);
 #else
-		fprintf (stderr, msg(/*%s: illegal option -- %c&#10;*/309), argv[0], c);
+		fprintf (stderr, msg(/*%s: illegal option -- %c\n*/309), argv[0], c);
 #endif
 	      }
 	    else
 	      {
 #if defined _LIBC && defined USE_IN_LIBIO
-		n = __asprintf (&buf, msg(/*%s: invalid option -- %c&#10;*/310),
+		n = __asprintf (&buf, msg(/*%s: invalid option -- %c\n*/310),
 				argv[0], c);
 #else
-		fprintf (stderr, msg(/*%s: invalid option -- %c&#10;*/310), argv[0], c);
+		fprintf (stderr, msg(/*%s: invalid option -- %c\n*/310), argv[0], c);
 #endif
 	      }
 
@@ -957,7 +957,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		char *buf;
 
 		if (__asprintf (&buf,
-				msg(/*%s: option requires an argument -- %c&#10;*/306),
+				msg(/*%s: option requires an argument -- %c\n*/306),
 				argv[0], c) >= 0)
 		  {
 		    if (_IO_fwide (stderr, 0) > 0)
@@ -968,7 +968,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		    free (buf);
 		  }
 #else
-		fprintf (stderr, msg(/*%s: option requires an argument -- %c&#10;*/306),
+		fprintf (stderr, msg(/*%s: option requires an argument -- %c\n*/306),
 			 argv[0], c);
 #endif
 	      }
@@ -1020,7 +1020,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		char *buf;
 
-		if (__asprintf (&buf, msg(/*%s: option `-W %s' is ambiguous&#10;*/301),
+		if (__asprintf (&buf, msg(/*%s: option `-W %s' is ambiguous\n*/301),
 				argv[0], argv[optind]) >= 0)
 		  {
 		    if (_IO_fwide (stderr, 0) > 0)
@@ -1031,7 +1031,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		    free (buf);
 		  }
 #else
-		fprintf (stderr, msg(/*%s: option `-W %s' is ambiguous&#10;*/301),
+		fprintf (stderr, msg(/*%s: option `-W %s' is ambiguous\n*/301),
 			 argv[0], argv[optind]);
 #endif
 	      }
@@ -1055,7 +1055,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 			char *buf;
 
-			if (__asprintf (&buf, msg(/*%s: option `-W %s' doesn't allow an argument&#10;*/304),
+			if (__asprintf (&buf, msg(/*%s: option `-W %s' doesn't allow an argument\n*/304),
 					argv[0], pfound->name) >= 0)
 			  {
 			    if (_IO_fwide (stderr, 0) > 0)
@@ -1066,7 +1066,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			    free (buf);
 			  }
 #else
-			fprintf (stderr, msg(/*%s: option `-W %s' doesn't allow an argument&#10;*/304),
+			fprintf (stderr, msg(/*%s: option `-W %s' doesn't allow an argument\n*/304),
 				 argv[0], pfound->name);
 #endif
 		      }
@@ -1086,7 +1086,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 			char *buf;
 
-			if (__asprintf (&buf, msg(/*%s: option `%s' requires an argument&#10;*/305),
+			if (__asprintf (&buf, msg(/*%s: option `%s' requires an argument\n*/305),
 					argv[0], argv[optind - 1]) >= 0)
 			  {
 			    if (_IO_fwide (stderr, 0) > 0)
@@ -1098,7 +1098,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			  }
 #else
 			fprintf (stderr,
-				 msg(/*%s: option `%s' requires an argument&#10;*/305),
+				 msg(/*%s: option `%s' requires an argument\n*/305),
 				 argv[0], argv[optind - 1]);
 #endif
 		      }
@@ -1151,7 +1151,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		    char *buf;
 
-		    if (__asprintf (&buf, msg(/*%s: option requires an argument -- %c&#10;*/306),
+		    if (__asprintf (&buf, msg(/*%s: option requires an argument -- %c\n*/306),
 				    argv[0], c) >= 0)
 		      {
 			if (_IO_fwide (stderr, 0) > 0)
@@ -1163,7 +1163,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		      }
 #else
 		    fprintf (stderr,
-			     msg(/*%s: option requires an argument -- %c&#10;*/306),
+			     msg(/*%s: option requires an argument -- %c\n*/306),
 			     argv[0], c);
 #endif
 		  }
